# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_table.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_table.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as zetasql_dot_public_dot_annotation__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!zetasql/public/simple_table.proto\x12\x07zetasql\x1a\x1fzetasql/public/annotation.proto\x1a\x19zetasql/public/type.proto\":\n\x1cSimpleAnonymizationInfoProto\x12\x1a\n\x12userid_column_name\x18\x01 \x03(\t\"\xfd\x02\n\x10SimpleTableProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x16\n\x0eis_value_table\x18\x03 \x01(\x08\x12*\n\x06\x63olumn\x18\x04 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProto\x12 \n\x18primary_key_column_index\x18\t \x03(\x05\x12!\n\x19row_identity_column_index\x18\x0b \x03(\x05\x12\x17\n\x0fname_in_catalog\x18\x05 \x01(\t\x12#\n\x1b\x61llow_anonymous_column_name\x18\x06 \x01(\x08\x12$\n\x1c\x61llow_duplicate_column_names\x18\x07 \x01(\x08\x12\x41\n\x12\x61nonymization_info\x18\x08 \x01(\x0b\x32%.zetasql.SimpleAnonymizationInfoProto\x12\x11\n\tfull_name\x18\n \x01(\t\"\xed\x01\n\x18\x45xpressionAttributeProto\x12\x19\n\x11\x65xpression_string\x18\x08 \x01(\t\x12I\n\x0f\x65xpression_kind\x18\t \x01(\x0e\x32\x30.zetasql.ExpressionAttributeProto.ExpressionKind\x12%\n\x19row_identity_column_index\x18\n \x03(\x05\x42\x02\x10\x01\"D\n\x0e\x45xpressionKind\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tGENERATED\x10\x01\x12\x16\n\x12MEASURE_EXPRESSION\x10\x02\"\xbe\x02\n\x11SimpleColumnProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x18\n\x10is_pseudo_column\x18\x03 \x01(\x08\x12 \n\x12is_writable_column\x18\x04 \x01(\x08:\x04true\x12(\n can_update_unwritable_to_default\x18\x06 \x01(\x08\x12\x33\n\x0e\x61nnotation_map\x18\x05 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProto\x12 \n\x11has_default_value\x18\x07 \x01(\x08:\x05\x66\x61lse\x12<\n\x11\x63olumn_expression\x18\x08 \x01(\x0b\x32!.zetasql.ExpressionAttributeProtoB\'\n\x12\x63om.google.zetasqlB\x11SimpleTableProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_table_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\021SimpleTableProtos'
  _globals['_EXPRESSIONATTRIBUTEPROTO'].fields_by_name['row_identity_column_index']._loaded_options = None
  _globals['_EXPRESSIONATTRIBUTEPROTO'].fields_by_name['row_identity_column_index']._serialized_options = b'\020\001'
  _globals['_SIMPLEANONYMIZATIONINFOPROTO']._serialized_start=106
  _globals['_SIMPLEANONYMIZATIONINFOPROTO']._serialized_end=164
  _globals['_SIMPLETABLEPROTO']._serialized_start=167
  _globals['_SIMPLETABLEPROTO']._serialized_end=548
  _globals['_EXPRESSIONATTRIBUTEPROTO']._serialized_start=551
  _globals['_EXPRESSIONATTRIBUTEPROTO']._serialized_end=788
  _globals['_EXPRESSIONATTRIBUTEPROTO_EXPRESSIONKIND']._serialized_start=720
  _globals['_EXPRESSIONATTRIBUTEPROTO_EXPRESSIONKIND']._serialized_end=788
  _globals['_SIMPLECOLUMNPROTO']._serialized_start=791
  _globals['_SIMPLECOLUMNPROTO']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
