"""Generated protocol buffer Python modules.

This package contains auto-generated code from .proto files.
Do not edit these files manually - they will be overwritten.

To regenerate:
    ./scripts/build_protos.sh
"""
