# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import builtin_function_pb2 as zetasql_dot_public_dot_builtin__function__pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as zetasql_dot_public_dot_options__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_node_kind_pb2 as zetasql_dot_resolved__ast_dot_resolved__node__kind__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bzetasql/proto/options.proto\x12\x07zetasql\x1a%zetasql/public/builtin_function.proto\x1a\x1czetasql/public/options.proto\x1a\x19zetasql/public/type.proto\x1a-zetasql/resolved_ast/resolved_node_kind.proto\"\x97\x02\n\"ZetaSQLBuiltinFunctionOptionsProto\x12\x37\n\x10language_options\x18\x01 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12:\n\x14include_function_ids\x18\x02 \x03(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12:\n\x14\x65xclude_function_ids\x18\x03 \x03(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12@\n\x1a\x65nabled_rewrites_map_entry\x18\x04 \x03(\x0b\x32\x1c.zetasql.EnabledRewriteProto\"O\n\x13\x45nabledRewriteProto\x12)\n\x03key\x18\x01 \x01(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12\r\n\x05value\x18\x02 \x01(\x08\"\x91\x03\n\x14LanguageOptionsProto\x12\x39\n\x14name_resolution_mode\x18\x02 \x01(\x0e\x32\x1b.zetasql.NameResolutionMode\x12*\n\x0cproduct_mode\x18\x03 \x01(\x0e\x32\x14.zetasql.ProductMode\x12\"\n\x1a\x65rror_on_deprecated_syntax\x18\x04 \x01(\x08\x12;\n\x19\x65nabled_language_features\x18\x05 \x03(\x0e\x32\x18.zetasql.LanguageFeature\x12<\n\x19supported_statement_kinds\x18\x06 \x03(\x0e\x32\x19.zetasql.ResolvedNodeKind\x12&\n\x1esupported_generic_entity_types\x18\x07 \x03(\t\x12\x19\n\x11reserved_keywords\x18\x08 \x03(\t\x12*\n\"supported_generic_sub_entity_types\x18\t \x03(\tJ\x04\x08\x01\x10\x02\"\xba\x06\n\x1b\x41llowedHintsAndOptionsProto\x12 \n\x18\x64isallow_unknown_options\x18\x01 \x01(\x08\x12-\n%disallow_unknown_hints_with_qualifier\x18\x02 \x03(\t\x12<\n\x04hint\x18\x03 \x03(\x0b\x32..zetasql.AllowedHintsAndOptionsProto.HintProto\x12@\n\x06option\x18\x04 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12N\n\x14\x61nonymization_option\x18\x05 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12U\n\x1b\x64ifferential_privacy_option\x18\x06 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12\'\n\x1f\x64isallow_duplicate_option_names\x18\x07 \x01(\x08\x1ai\n\tHintProto\x12\x11\n\tqualifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x19\n\x11\x61llow_unqualified\x18\x04 \x01(\x08\x1a\x8e\x02\n\x0bOptionProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12V\n\x0eresolving_kind\x18\x03 \x01(\x0e\x32>.zetasql.AllowedHintsAndOptionsProto.OptionProto.ResolvingKind\x12\x19\n\x11\x61llow_alter_array\x18\x04 \x01(\x08\"\\\n\rResolvingKind\x12+\n\'CONSTANT_OR_EMPTY_NAME_SCOPE_IDENTIFIER\x10\x00\x12\x1e\n\x1a\x46ROM_NAME_SCOPE_IDENTIFIER\x10\x01\"\xa2\x0c\n\x14\x41nalyzerOptionsProto\x12\x37\n\x10language_options\x18\x01 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12K\n\x10query_parameters\x18\x02 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12\x37\n\x1bpositional_query_parameters\x18\x0c \x03(\x0b\x32\x12.zetasql.TypeProto\x12M\n\x12\x65xpression_columns\x18\x03 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12U\n\x1ain_scope_expression_column\x18\x04 \x01(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12M\n\x12\x64\x64l_pseudo_columns\x18\x0f \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12\x35\n\x12\x65rror_message_mode\x18\x06 \x01(\x0e\x32\x19.zetasql.ErrorMessageMode\x12\x18\n\x10\x64\x65\x66\x61ult_timezone\x18\x07 \x01(\t\x12\x33\n+create_new_column_for_each_projected_output\x18\x14 \x01(\x08\x12\x1c\n\x14prune_unused_columns\x18\t \x01(\x08\x12#\n\x1b\x61llow_undeclared_parameters\x18\n \x01(\x08\x12.\n\x0eparameter_mode\x18\r \x01(\x0e\x32\x16.zetasql.ParameterMode\x12G\n\x19\x61llowed_hints_and_options\x18\x0b \x01(\x0b\x32$.zetasql.AllowedHintsAndOptionsProto\x12\x34\n\x11statement_context\x18\x0e \x01(\x0e\x32\x19.zetasql.StatementContext\x12\x1f\n\x17preserve_column_aliases\x18\x11 \x01(\x08\x12K\n\x10system_variables\x18\x12 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.SystemVariableProto\x12/\n\x13target_column_types\x18\x13 \x03(\x0b\x32\x12.zetasql.TypeProto\x12\x35\n\x10\x65nabled_rewrites\x18\x15 \x03(\x0e\x32\x1b.zetasql.ResolvedASTRewrite\x12\x44\n\x1aparse_location_record_type\x18\x17 \x01(\x0e\x32 .zetasql.ParseLocationRecordType\x12!\n\x19preserve_unnecessary_cast\x18\x18 \x01(\x08\x12+\n#default_anon_function_report_format\x18\x19 \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_anon_kappa_value\x18\x1a \x01(\x03\x12\x30\n\x0frewrite_options\x18\x1c \x01(\x0b\x32\x17.zetasql.RewriteOptions\x12\x42\n:replace_table_not_found_error_with_tvf_error_if_applicable\x18\x1d \x01(\x08\x12/\n\'log_impact_of_lateral_column_references\x18\x1f \x01(\x08\x1a\x45\n\x13QueryParameterProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x1aJ\n\x13SystemVariableProto\x12\x11\n\tname_path\x18\x01 \x03(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProtoJ\x04\x08\x08\x10\tJ\x04\x08\x16\x10\x17J\x04\x08\x10\x10\x11J\x04\x08\x1b\x10\x1c\x42)\n\x12\x63om.google.zetasqlB\x13ZetaSQLOptionsProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\023ZetaSQLOptionsProto'
  _globals['_ZETASQLBUILTINFUNCTIONOPTIONSPROTO']._serialized_start=184
  _globals['_ZETASQLBUILTINFUNCTIONOPTIONSPROTO']._serialized_end=463
  _globals['_ENABLEDREWRITEPROTO']._serialized_start=465
  _globals['_ENABLEDREWRITEPROTO']._serialized_end=544
  _globals['_LANGUAGEOPTIONSPROTO']._serialized_start=547
  _globals['_LANGUAGEOPTIONSPROTO']._serialized_end=948
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO']._serialized_start=951
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO']._serialized_end=1777
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_HINTPROTO']._serialized_start=1399
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_HINTPROTO']._serialized_end=1504
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO']._serialized_start=1507
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO']._serialized_end=1777
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO_RESOLVINGKIND']._serialized_start=1685
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO_RESOLVINGKIND']._serialized_end=1777
  _globals['_ANALYZEROPTIONSPROTO']._serialized_start=1780
  _globals['_ANALYZEROPTIONSPROTO']._serialized_end=3350
  _globals['_ANALYZEROPTIONSPROTO_QUERYPARAMETERPROTO']._serialized_start=3181
  _globals['_ANALYZEROPTIONSPROTO_QUERYPARAMETERPROTO']._serialized_end=3250
  _globals['_ANALYZEROPTIONSPROTO_SYSTEMVARIABLEPROTO']._serialized_start=3252
  _globals['_ANALYZEROPTIONSPROTO_SYSTEMVARIABLEPROTO']._serialized_end=3326
# @@protoc_insertion_point(module_scope)
