# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/internal_fix_suggestion.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/internal_fix_suggestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.proto import internal_error_location_pb2 as zetasql_dot_proto_dot_internal__error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+zetasql/proto/internal_fix_suggestion.proto\x12\x07zetasql\x1a+zetasql/proto/internal_error_location.proto\"Q\n\x10InternalFixRange\x12-\n\x05start\x18\x01 \x01(\x0b\x32\x1e.zetasql.InternalErrorLocation\x12\x0e\n\x06length\x18\x02 \x01(\x05\"N\n\x10InternalTextEdit\x12(\n\x05range\x18\x01 \x01(\x0b\x32\x19.zetasql.InternalFixRange\x12\x10\n\x08new_text\x18\x02 \x01(\t\">\n\rInternalEdits\x12-\n\ntext_edits\x18\x01 \x03(\x0b\x32\x19.zetasql.InternalTextEdit\"C\n\x0bInternalFix\x12\r\n\x05title\x18\x01 \x01(\t\x12%\n\x05\x65\x64its\x18\x02 \x01(\x0b\x32\x16.zetasql.InternalEdits\"L\n\x1bInternalErrorFixSuggestions\x12-\n\x0f\x66ix_suggestions\x18\x01 \x03(\x0b\x32\x14.zetasql.InternalFixB1\n\x12\x63om.google.zetasqlB\x1bInternalFixSuggestionProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.internal_fix_suggestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033InternalFixSuggestionProtos'
  _globals['_INTERNALFIXRANGE']._serialized_start=101
  _globals['_INTERNALFIXRANGE']._serialized_end=182
  _globals['_INTERNALTEXTEDIT']._serialized_start=184
  _globals['_INTERNALTEXTEDIT']._serialized_end=262
  _globals['_INTERNALEDITS']._serialized_start=264
  _globals['_INTERNALEDITS']._serialized_end=326
  _globals['_INTERNALFIX']._serialized_start=328
  _globals['_INTERNALFIX']._serialized_end=395
  _globals['_INTERNALERRORFIXSUGGESTIONS']._serialized_start=397
  _globals['_INTERNALERRORFIXSUGGESTIONS']._serialized_end=473
# @@protoc_insertion_point(module_scope)
