from zetasql.wasi._pb2.zetasql.public.proto import type_annotation_pb2 as _type_annotation_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
