# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/error_location.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/error_location.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#zetasql/public/error_location.proto\x12\x07zetasql\"\xb5\x01\n\rErrorLocation\x12\x0f\n\x04line\x18\x01 \x01(\x05:\x01\x31\x12\x11\n\x06\x63olumn\x18\x02 \x01(\x05:\x01\x31\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x1f\n\x17input_start_line_offset\x18\x05 \x01(\x05\x12!\n\x19input_start_column_offset\x18\x06 \x01(\x05\x12*\n\x0c\x65rror_source\x18\x04 \x03(\x0b\x32\x14.zetasql.ErrorSource\"x\n\x0b\x45rrorSource\x12\x15\n\rerror_message\x18\x01 \x01(\t\x12\"\n\x1a\x65rror_message_caret_string\x18\x02 \x01(\t\x12.\n\x0e\x65rror_location\x18\x03 \x01(\x0b\x32\x16.zetasql.ErrorLocationB\x14\n\x12\x63om.google.zetasql')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.error_location_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql'
  _globals['_ERRORLOCATION']._serialized_start=49
  _globals['_ERRORLOCATION']._serialized_end=230
  _globals['_ERRORSOURCE']._serialized_start=232
  _globals['_ERRORSOURCE']._serialized_end=352
# @@protoc_insertion_point(module_scope)
