# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/reference_impl/evaluator_table_iterator.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/reference_impl/evaluator_table_iterator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5zetasql/reference_impl/evaluator_table_iterator.proto\x12\x07zetasql\"S\n\x1b\x45valuatorTableIteratorProto\x12\x1c\n\x14location_byte_offset\x18\x01 \x01(\x05\x12\x16\n\x0enext_row_count\x18\x02 \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.reference_impl.evaluator_table_iterator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVALUATORTABLEITERATORPROTO']._serialized_start=66
  _globals['_EVALUATORTABLEITERATORPROTO']._serialized_end=149
# @@protoc_insertion_point(module_scope)
