# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/resolved_node_kind.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/resolved_node_kind.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/resolved_ast/resolved_node_kind.proto\x12\x07zetasql*\xc9J\n\x10ResolvedNodeKind\x12\x14\n\x10RESOLVED_LITERAL\x10\x03\x12\x16\n\x12RESOLVED_PARAMETER\x10\x04\x12\x1e\n\x1aRESOLVED_EXPRESSION_COLUMN\x10\x05\x12 \n\x1bRESOLVED_CATALOG_COLUMN_REF\x10\xce\x01\x12\x17\n\x13RESOLVED_COLUMN_REF\x10\x06\x12\'\n\"RESOLVED_GROUPING_SET_MULTI_COLUMN\x10\xed\x01\x12\x15\n\x11RESOLVED_CONSTANT\x10g\x12\x1d\n\x18RESOLVED_SYSTEM_VARIABLE\x10\x8b\x01\x12\x1b\n\x16RESOLVED_INLINE_LAMBDA\x10\x9f\x01\x12\x16\n\x11RESOLVED_SEQUENCE\x10\xe9\x01\x12\x1e\n\x19RESOLVED_FILTER_FIELD_ARG\x10\xad\x01\x12\x1a\n\x15RESOLVED_FILTER_FIELD\x10\xae\x01\x12\x1a\n\x16RESOLVED_FUNCTION_CALL\x10\x08\x12$\n RESOLVED_AGGREGATE_FUNCTION_CALL\x10\t\x12#\n\x1fRESOLVED_ANALYTIC_FUNCTION_CALL\x10\n\x12#\n\x1eRESOLVED_EXTENDED_CAST_ELEMENT\x10\x97\x01\x12\x1b\n\x16RESOLVED_EXTENDED_CAST\x10\x9e\x01\x12\x11\n\rRESOLVED_CAST\x10\x0b\x12\x18\n\x14RESOLVED_MAKE_STRUCT\x10\x0c\x12\x17\n\x13RESOLVED_MAKE_PROTO\x10\r\x12\x1d\n\x19RESOLVED_MAKE_PROTO_FIELD\x10\x0e\x12\x1d\n\x19RESOLVED_GET_STRUCT_FIELD\x10\x0f\x12\x1c\n\x18RESOLVED_GET_PROTO_FIELD\x10\x10\x12\x1c\n\x17RESOLVED_GET_JSON_FIELD\x10\xa5\x01\x12\x1b\n\x16RESOLVED_GET_ROW_FIELD\x10\xba\x02\x12\x15\n\x10RESOLVED_FLATTEN\x10\x95\x01\x12\x1b\n\x16RESOLVED_FLATTENED_ARG\x10\x96\x01\x12 \n\x1bRESOLVED_REPLACE_FIELD_ITEM\x10\x80\x01\x12\x1b\n\x16RESOLVED_REPLACE_FIELD\x10\x81\x01\x12\x1d\n\x18RESOLVED_GET_PROTO_ONEOF\x10\x82\x01\x12\x1a\n\x16RESOLVED_SUBQUERY_EXPR\x10\x11\x12\x17\n\x12RESOLVED_WITH_EXPR\x10\xc5\x01\x12\"\n\x1dRESOLVED_EXECUTE_AS_ROLE_SCAN\x10\xcf\x01\x12\x12\n\x0eRESOLVED_MODEL\x10m\x12\x18\n\x13RESOLVED_CONNECTION\x10\x8d\x01\x12\x18\n\x13RESOLVED_DESCRIPTOR\x10\x90\x01\x12\x1c\n\x18RESOLVED_SINGLE_ROW_SCAN\x10\x13\x12!\n\x1cRESOLVED_UNSET_ARGUMENT_SCAN\x10\xad\x02\x12\x17\n\x13RESOLVED_TABLE_SCAN\x10\x14\x12\x16\n\x12RESOLVED_JOIN_SCAN\x10\x15\x12\x17\n\x13RESOLVED_ARRAY_SCAN\x10\x16\x12\x1a\n\x16RESOLVED_COLUMN_HOLDER\x10\x17\x12\x18\n\x14RESOLVED_FILTER_SCAN\x10\x18\x12\x1b\n\x16RESOLVED_GROUPING_CALL\x10\xf1\x01\x12\x1f\n\x1aRESOLVED_GROUPING_SET_LIST\x10\xae\x02\x12\"\n\x1dRESOLVED_GROUPING_SET_PRODUCT\x10\xaf\x02\x12\x19\n\x15RESOLVED_GROUPING_SET\x10]\x12\x14\n\x0fRESOLVED_ROLLUP\x10\xef\x01\x12\x12\n\rRESOLVED_CUBE\x10\xf0\x01\x12\x1b\n\x17RESOLVED_AGGREGATE_SCAN\x10\x19\x12&\n\"RESOLVED_ANONYMIZED_AGGREGATE_SCAN\x10p\x12\x31\n,RESOLVED_DIFFERENTIAL_PRIVACY_AGGREGATE_SCAN\x10\xdd\x01\x12\x32\n-RESOLVED_AGGREGATION_THRESHOLD_AGGREGATE_SCAN\x10\xe4\x01\x12\x1f\n\x1bRESOLVED_SET_OPERATION_ITEM\x10^\x12\x1f\n\x1bRESOLVED_SET_OPERATION_SCAN\x10\x1a\x12\x1a\n\x16RESOLVED_ORDER_BY_SCAN\x10\x1b\x12\x1e\n\x1aRESOLVED_LIMIT_OFFSET_SCAN\x10\x1c\x12\x1a\n\x16RESOLVED_WITH_REF_SCAN\x10\x1d\x12\x1a\n\x16RESOLVED_ANALYTIC_SCAN\x10\x1e\x12\x18\n\x14RESOLVED_SAMPLE_SCAN\x10\x1f\x12\x1c\n\x18RESOLVED_COMPUTED_COLUMN\x10 \x12&\n!RESOLVED_DEFERRED_COMPUTED_COLUMN\x10\xff\x01\x12\x1a\n\x16RESOLVED_ORDER_BY_ITEM\x10!\x12\x1f\n\x1bRESOLVED_COLUMN_ANNOTATIONS\x10h\x12\"\n\x1eRESOLVED_GENERATED_COLUMN_INFO\x10i\x12\"\n\x1dRESOLVED_COLUMN_DEFAULT_VALUE\x10\xbc\x01\x12\x1e\n\x1aRESOLVED_COLUMN_DEFINITION\x10[\x12\x18\n\x14RESOLVED_PRIMARY_KEY\x10\\\x12\x18\n\x14RESOLVED_FOREIGN_KEY\x10n\x12\x1d\n\x19RESOLVED_CHECK_CONSTRAINT\x10q\x12\x1a\n\x16RESOLVED_OUTPUT_COLUMN\x10\"\x12\x1b\n\x16RESOLVED_OUTPUT_SCHEMA\x10\x97\x02\x12\x19\n\x15RESOLVED_PROJECT_SCAN\x10#\x12\x14\n\x10RESOLVED_TVFSCAN\x10Q\x12\x1d\n\x18RESOLVED_GROUP_ROWS_SCAN\x10\xb0\x01\x12\x1e\n\x1aRESOLVED_FUNCTION_ARGUMENT\x10R\x12\x19\n\x15RESOLVED_EXPLAIN_STMT\x10%\x12\x30\n+RESOLVED_STATEMENT_WITH_PIPE_OPERATORS_STMT\x10\xb6\x02\x12\x17\n\x13RESOLVED_QUERY_STMT\x10&\x12$\n\x1fRESOLVED_GENERALIZED_QUERY_STMT\x10\x9a\x02\x12\x18\n\x13RESOLVED_MULTI_STMT\x10\x9f\x02\x12$\n\x1fRESOLVED_CREATE_WITH_ENTRY_STMT\x10\xa0\x02\x12!\n\x1dRESOLVED_CREATE_DATABASE_STMT\x10_\x12\x17\n\x13RESOLVED_INDEX_ITEM\x10`\x12\x18\n\x14RESOLVED_UNNEST_ITEM\x10~\x12\x1e\n\x1aRESOLVED_CREATE_INDEX_STMT\x10\x61\x12 \n\x1bRESOLVED_CREATE_SCHEMA_STMT\x10\x9d\x01\x12)\n$RESOLVED_CREATE_EXTERNAL_SCHEMA_STMT\x10\xf9\x01\x12\x1e\n\x1aRESOLVED_CREATE_TABLE_STMT\x10Z\x12(\n$RESOLVED_CREATE_TABLE_AS_SELECT_STMT\x10(\x12(\n#RESOLVED_CREATE_MODEL_ALIASED_QUERY\x10\xe2\x01\x12\x1e\n\x1aRESOLVED_CREATE_MODEL_STMT\x10k\x12\x1d\n\x19RESOLVED_CREATE_VIEW_STMT\x10)\x12$\n\x1fRESOLVED_WITH_PARTITION_COLUMNS\x10\x99\x01\x12(\n#RESOLVED_CREATE_SNAPSHOT_TABLE_STMT\x10\xb6\x01\x12\'\n#RESOLVED_CREATE_EXTERNAL_TABLE_STMT\x10*\x12\x1f\n\x1aRESOLVED_EXPORT_MODEL_STMT\x10\x98\x01\x12\x1d\n\x19RESOLVED_EXPORT_DATA_STMT\x10+\x12\"\n\x1dRESOLVED_EXPORT_METADATA_STMT\x10\xea\x01\x12\x1e\n\x1aRESOLVED_DEFINE_TABLE_STMT\x10,\x12\x1a\n\x16RESOLVED_DESCRIBE_STMT\x10-\x12\x16\n\x12RESOLVED_SHOW_STMT\x10.\x12\x17\n\x13RESOLVED_BEGIN_STMT\x10/\x12!\n\x1dRESOLVED_SET_TRANSACTION_STMT\x10x\x12\x18\n\x14RESOLVED_COMMIT_STMT\x10\x30\x12\x1a\n\x16RESOLVED_ROLLBACK_STMT\x10\x31\x12\x1d\n\x19RESOLVED_START_BATCH_STMT\x10z\x12\x1b\n\x17RESOLVED_RUN_BATCH_STMT\x10{\x12\x1d\n\x19RESOLVED_ABORT_BATCH_STMT\x10|\x12\x16\n\x12RESOLVED_DROP_STMT\x10\x32\x12(\n$RESOLVED_DROP_MATERIALIZED_VIEW_STMT\x10y\x12&\n!RESOLVED_DROP_SNAPSHOT_TABLE_STMT\x10\xb7\x01\x12 \n\x1bRESOLVED_RECURSIVE_REF_SCAN\x10\x93\x01\x12&\n!RESOLVED_RECURSION_DEPTH_MODIFIER\x10\x80\x02\x12\x1c\n\x17RESOLVED_RECURSIVE_SCAN\x10\x94\x01\x12\x16\n\x12RESOLVED_WITH_SCAN\x10\x33\x12\x17\n\x13RESOLVED_WITH_ENTRY\x10\x34\x12\x13\n\x0fRESOLVED_OPTION\x10\x35\x12 \n\x1cRESOLVED_WINDOW_PARTITIONING\x10\x36\x12\x1c\n\x18RESOLVED_WINDOW_ORDERING\x10\x37\x12\x19\n\x15RESOLVED_WINDOW_FRAME\x10\x38\x12$\n RESOLVED_ANALYTIC_FUNCTION_GROUP\x10\x39\x12\x1e\n\x1aRESOLVED_WINDOW_FRAME_EXPR\x10:\x12\x15\n\x11RESOLVED_DMLVALUE\x10;\x12\x17\n\x13RESOLVED_DMLDEFAULT\x10<\x12\x18\n\x14RESOLVED_ASSERT_STMT\x10\x62\x12!\n\x1dRESOLVED_ASSERT_ROWS_MODIFIED\x10=\x12 \n\x1bRESOLVED_ON_CONFLICT_CLAUSE\x10\x99\x02\x12\x17\n\x13RESOLVED_INSERT_ROW\x10>\x12\x18\n\x14RESOLVED_INSERT_STMT\x10?\x12\x18\n\x14RESOLVED_DELETE_STMT\x10@\x12\x18\n\x14RESOLVED_UPDATE_ITEM\x10\x41\x12 \n\x1cRESOLVED_UPDATE_ITEM_ELEMENT\x10\x66\x12\x18\n\x14RESOLVED_UPDATE_STMT\x10\x42\x12\x17\n\x13RESOLVED_MERGE_WHEN\x10\x64\x12\x17\n\x13RESOLVED_MERGE_STMT\x10\x65\x12\x1b\n\x16RESOLVED_TRUNCATE_STMT\x10\x85\x01\x12\x19\n\x14RESOLVED_OBJECT_UNIT\x10\xc8\x01\x12\x16\n\x12RESOLVED_PRIVILEGE\x10\x43\x12\x17\n\x13RESOLVED_GRANT_STMT\x10\x45\x12\x18\n\x14RESOLVED_REVOKE_STMT\x10\x46\x12!\n\x1cRESOLVED_ALTER_DATABASE_STMT\x10\x86\x01\x12\x1e\n\x19RESOLVED_ALTER_INDEX_STMT\x10\xa4\x02\x12)\n%RESOLVED_ALTER_MATERIALIZED_VIEW_STMT\x10\x7f\x12$\n\x1fRESOLVED_ALTER_APPROX_VIEW_STMT\x10\xec\x01\x12\x1f\n\x1aRESOLVED_ALTER_SCHEMA_STMT\x10\xa0\x01\x12(\n#RESOLVED_ALTER_EXTERNAL_SCHEMA_STMT\x10\xfa\x01\x12\x1e\n\x19RESOLVED_ALTER_MODEL_STMT\x10\xcd\x01\x12\x1d\n\x19RESOLVED_ALTER_TABLE_STMT\x10s\x12\x1c\n\x18RESOLVED_ALTER_VIEW_STMT\x10v\x12\x1f\n\x1bRESOLVED_SET_OPTIONS_ACTION\x10u\x12%\n RESOLVED_ALTER_SUB_ENTITY_ACTION\x10\xca\x01\x12#\n\x1eRESOLVED_ADD_SUB_ENTITY_ACTION\x10\xcb\x01\x12$\n\x1fRESOLVED_DROP_SUB_ENTITY_ACTION\x10\xcc\x01\x12\x1f\n\x1aRESOLVED_ADD_COLUMN_ACTION\x10\x83\x01\x12*\n%RESOLVED_ADD_COLUMN_IDENTIFIER_ACTION\x10\xa5\x02\x12\x1c\n\x17RESOLVED_REBUILD_ACTION\x10\xa6\x02\x12#\n\x1eRESOLVED_ADD_CONSTRAINT_ACTION\x10\xa3\x01\x12$\n\x1fRESOLVED_DROP_CONSTRAINT_ACTION\x10\xa4\x01\x12%\n RESOLVED_DROP_PRIMARY_KEY_ACTION\x10\xb8\x01\x12)\n$RESOLVED_ALTER_COLUMN_OPTIONS_ACTION\x10\xa9\x01\x12/\n*RESOLVED_ALTER_COLUMN_DROP_NOT_NULL_ACTION\x10\xb2\x01\x12\x30\n+RESOLVED_ALTER_COLUMN_DROP_GENERATED_ACTION\x10\xf3\x01\x12/\n*RESOLVED_ALTER_COLUMN_SET_GENERATED_ACTION\x10\xb0\x02\x12/\n*RESOLVED_ALTER_COLUMN_SET_DATA_TYPE_ACTION\x10\xb5\x01\x12-\n(RESOLVED_ALTER_COLUMN_SET_DEFAULT_ACTION\x10\xc6\x01\x12.\n)RESOLVED_ALTER_COLUMN_DROP_DEFAULT_ACTION\x10\xc7\x01\x12 \n\x1bRESOLVED_DROP_COLUMN_ACTION\x10\x84\x01\x12\"\n\x1dRESOLVED_RENAME_COLUMN_ACTION\x10\xb9\x01\x12\x1b\n\x16RESOLVED_SET_AS_ACTION\x10\x9c\x01\x12 \n\x1bRESOLVED_SET_COLLATE_CLAUSE\x10\xbb\x01\x12)\n%RESOLVED_ALTER_TABLE_SET_OPTIONS_STMT\x10G\x12\x18\n\x14RESOLVED_RENAME_STMT\x10H\x12/\n*RESOLVED_CREATE_PRIVILEGE_RESTRICTION_STMT\x10\xbf\x01\x12*\n&RESOLVED_CREATE_ROW_ACCESS_POLICY_STMT\x10I\x12-\n(RESOLVED_DROP_PRIVILEGE_RESTRICTION_STMT\x10\xc0\x01\x12(\n$RESOLVED_DROP_ROW_ACCESS_POLICY_STMT\x10J\x12\x1d\n\x18RESOLVED_DROP_INDEX_STMT\x10\xf2\x01\x12\x1d\n\x18RESOLVED_GRANT_TO_ACTION\x10\x87\x01\x12 \n\x1bRESOLVED_RESTRICT_TO_ACTION\x10\xc1\x01\x12+\n&RESOLVED_ADD_TO_RESTRICTEE_LIST_ACTION\x10\xc2\x01\x12\x30\n+RESOLVED_REMOVE_FROM_RESTRICTEE_LIST_ACTION\x10\xc3\x01\x12!\n\x1cRESOLVED_FILTER_USING_ACTION\x10\x88\x01\x12 \n\x1bRESOLVED_REVOKE_FROM_ACTION\x10\x89\x01\x12\x1e\n\x19RESOLVED_RENAME_TO_ACTION\x10\x8a\x01\x12.\n)RESOLVED_ALTER_PRIVILEGE_RESTRICTION_STMT\x10\xc4\x01\x12)\n%RESOLVED_ALTER_ROW_ACCESS_POLICY_STMT\x10K\x12\x30\n+RESOLVED_ALTER_ALL_ROW_ACCESS_POLICIES_STMT\x10\x91\x01\x12!\n\x1dRESOLVED_CREATE_CONSTANT_STMT\x10\x63\x12!\n\x1dRESOLVED_CREATE_FUNCTION_STMT\x10L\x12\x19\n\x15RESOLVED_ARGUMENT_DEF\x10M\x12\x19\n\x15RESOLVED_ARGUMENT_REF\x10N\x12\'\n#RESOLVED_CREATE_TABLE_FUNCTION_STMT\x10X\x12#\n\x1fRESOLVED_RELATION_ARGUMENT_SCAN\x10Y\x12\x1a\n\x16RESOLVED_ARGUMENT_LIST\x10O\x12&\n\"RESOLVED_FUNCTION_SIGNATURE_HOLDER\x10T\x12\x1f\n\x1bRESOLVED_DROP_FUNCTION_STMT\x10P\x12&\n!RESOLVED_DROP_TABLE_FUNCTION_STMT\x10\xaf\x01\x12\x16\n\x12RESOLVED_CALL_STMT\x10S\x12\x18\n\x14RESOLVED_IMPORT_STMT\x10V\x12\x18\n\x14RESOLVED_MODULE_STMT\x10W\x12&\n\"RESOLVED_AGGREGATE_HAVING_MODIFIER\x10U\x12*\n&RESOLVED_CREATE_MATERIALIZED_VIEW_STMT\x10w\x12%\n RESOLVED_CREATE_APPROX_VIEW_STMT\x10\xeb\x01\x12\"\n\x1eRESOLVED_CREATE_PROCEDURE_STMT\x10}\x12(\n#RESOLVED_EXECUTE_IMMEDIATE_ARGUMENT\x10\x8f\x01\x12$\n\x1fRESOLVED_EXECUTE_IMMEDIATE_STMT\x10\x8c\x01\x12\x1d\n\x18RESOLVED_ASSIGNMENT_STMT\x10\x8e\x01\x12 \n\x1bRESOLVED_CREATE_ENTITY_STMT\x10\x9a\x01\x12\x1f\n\x1aRESOLVED_ALTER_ENTITY_STMT\x10\x9b\x01\x12\x1a\n\x15RESOLVED_PIVOT_COLUMN\x10\xa6\x01\x12\x18\n\x13RESOLVED_PIVOT_SCAN\x10\xa1\x01\x12\x1e\n\x19RESOLVED_RETURNING_CLAUSE\x10\xaa\x01\x12\x19\n\x14RESOLVED_UNPIVOT_ARG\x10\xab\x01\x12\x1a\n\x15RESOLVED_UNPIVOT_SCAN\x10\xac\x01\x12\"\n\x1dRESOLVED_MATCH_RECOGNIZE_SCAN\x10\x89\x02\x12\x1b\n\x16RESOLVED_MEASURE_GROUP\x10\x98\x02\x12\x31\n,RESOLVED_MATCH_RECOGNIZE_VARIABLE_DEFINITION\x10\x8a\x02\x12+\n&RESOLVED_MATCH_RECOGNIZE_PATTERN_EMPTY\x10\x8c\x02\x12,\n\'RESOLVED_MATCH_RECOGNIZE_PATTERN_ANCHOR\x10\x94\x02\x12\x32\n-RESOLVED_MATCH_RECOGNIZE_PATTERN_VARIABLE_REF\x10\x8d\x02\x12/\n*RESOLVED_MATCH_RECOGNIZE_PATTERN_OPERATION\x10\x8e\x02\x12\x34\n/RESOLVED_MATCH_RECOGNIZE_PATTERN_QUANTIFICATION\x10\x8f\x02\x12\x1d\n\x18RESOLVED_CLONE_DATA_STMT\x10\xb1\x01\x12#\n\x1eRESOLVED_TABLE_AND_COLUMN_INFO\x10\xb3\x01\x12\x1a\n\x15RESOLVED_ANALYZE_STMT\x10\xb4\x01\x12,\n\'RESOLVED_AUX_LOAD_DATA_PARTITION_FILTER\x10\xde\x01\x12 \n\x1bRESOLVED_AUX_LOAD_DATA_STMT\x10\xba\x01\x12(\n#RESOLVED_CREATE_PROPERTY_GRAPH_STMT\x10\xdf\x01\x12!\n\x1cRESOLVED_GRAPH_ELEMENT_TABLE\x10\xe0\x01\x12(\n#RESOLVED_GRAPH_NODE_TABLE_REFERENCE\x10\xe1\x01\x12!\n\x1cRESOLVED_GRAPH_ELEMENT_LABEL\x10\xe6\x01\x12(\n#RESOLVED_GRAPH_PROPERTY_DECLARATION\x10\xe7\x01\x12\'\n\"RESOLVED_GRAPH_PROPERTY_DEFINITION\x10\xe8\x01\x12/\n*RESOLVED_GRAPH_DYNAMIC_LABEL_SPECIFICATION\x10\xa2\x02\x12\x34\n/RESOLVED_GRAPH_DYNAMIC_PROPERTIES_SPECIFICATION\x10\xa3\x02\x12\x1c\n\x17RESOLVED_GRAPH_REF_SCAN\x10\xf6\x01\x12\x1f\n\x1aRESOLVED_GRAPH_LINEAR_SCAN\x10\xf7\x01\x12\x1e\n\x19RESOLVED_GRAPH_TABLE_SCAN\x10\xd0\x01\x12\x1d\n\x18RESOLVED_GRAPH_CALL_SCAN\x10\xab\x02\x12\x18\n\x13RESOLVED_GRAPH_SCAN\x10\xe5\x01\x12+\n&RESOLVED_GRAPH_PATH_PATTERN_QUANTIFIER\x10\xf5\x01\x12&\n!RESOLVED_GRAPH_PATH_SEARCH_PREFIX\x10\x84\x02\x12\x1d\n\x18RESOLVED_GRAPH_NODE_SCAN\x10\xd1\x01\x12\x1d\n\x18RESOLVED_GRAPH_EDGE_SCAN\x10\xd8\x01\x12(\n#RESOLVED_GRAPH_GET_ELEMENT_PROPERTY\x10\xd2\x01\x12#\n\x1eRESOLVED_GRAPH_LABEL_NARY_EXPR\x10\xd4\x01\x12\x19\n\x14RESOLVED_GRAPH_LABEL\x10\xd5\x01\x12#\n\x1eRESOLVED_GRAPH_WILD_CARD_LABEL\x10\xd6\x01\x12&\n!RESOLVED_GRAPH_ELEMENT_IDENTIFIER\x10\xd9\x01\x12$\n\x1fRESOLVED_GRAPH_ELEMENT_PROPERTY\x10\xda\x01\x12 \n\x1bRESOLVED_GRAPH_MAKE_ELEMENT\x10\xdb\x01\x12\x1d\n\x18RESOLVED_ARRAY_AGGREGATE\x10\x81\x02\x12\'\n\"RESOLVED_GRAPH_MAKE_ARRAY_VARIABLE\x10\x82\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_MODE\x10\x83\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_COST\x10\xaa\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_SCAN\x10\xdc\x01\x12(\n#RESOLVED_GRAPH_IS_LABELED_PREDICATE\x10\x86\x02\x12\x19\n\x14RESOLVED_UNDROP_STMT\x10\xe3\x01\x12\"\n\x1dRESOLVED_IDENTITY_COLUMN_INFO\x10\xf4\x01\x12\x1b\n\x16RESOLVED_DESCRIBE_SCAN\x10\xac\x02\x12\"\n\x1dRESOLVED_STATIC_DESCRIBE_SCAN\x10\xfb\x01\x12\x19\n\x14RESOLVED_ASSERT_SCAN\x10\xfc\x01\x12\x16\n\x11RESOLVED_LOG_SCAN\x10\x90\x02\x12\x1a\n\x15RESOLVED_PIPE_IF_SCAN\x10\x95\x02\x12\x1a\n\x15RESOLVED_PIPE_IF_CASE\x10\x96\x02\x12\x1c\n\x17RESOLVED_PIPE_FORK_SCAN\x10\x9b\x02\x12\x1b\n\x16RESOLVED_PIPE_TEE_SCAN\x10\xa1\x02\x12#\n\x1eRESOLVED_PIPE_EXPORT_DATA_SCAN\x10\x9d\x02\x12$\n\x1fRESOLVED_PIPE_CREATE_TABLE_SCAN\x10\x9e\x02\x12\x1e\n\x19RESOLVED_PIPE_INSERT_SCAN\x10\xa9\x02\x12\x19\n\x14RESOLVED_SUBPIPELINE\x10\x91\x02\x12$\n\x1fRESOLVED_SUBPIPELINE_INPUT_SCAN\x10\x92\x02\x12\x1e\n\x19RESOLVED_SUBPIPELINE_STMT\x10\xb4\x02\x12+\n&RESOLVED_GENERALIZED_QUERY_SUBPIPELINE\x10\x9c\x02\x12\x1a\n\x15RESOLVED_BARRIER_SCAN\x10\x85\x02\x12$\n\x1fRESOLVED_CREATE_CONNECTION_STMT\x10\x87\x02\x12#\n\x1eRESOLVED_ALTER_CONNECTION_STMT\x10\x88\x02\x12\x17\n\x12RESOLVED_LOCK_MODE\x10\x93\x02\x12\x1f\n\x1aRESOLVED_UPDATE_FIELD_ITEM\x10\xa7\x02\x12 \n\x1bRESOLVED_UPDATE_CONSTRUCTOR\x10\xa8\x02\x12\"\n\x1dRESOLVED_CREATE_SEQUENCE_STMT\x10\xb2\x02\x12!\n\x1cRESOLVED_ALTER_SEQUENCE_STMT\x10\xb3\x02\x12;\n.__ResolvedNodeKind__switch_must_have_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x42-\n\x12\x63om.google.zetasqlB\x17ZetaSQLResolvedNodeKind')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.resolved_node_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\027ZetaSQLResolvedNodeKind'
  _globals['_RESOLVEDNODEKIND']._serialized_start=59
  _globals['_RESOLVEDNODEKIND']._serialized_end=9604
# @@protoc_insertion_point(module_scope)
