from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class DateTimestampPart(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    __DateTimePart__switch_must_have_a_default__: _ClassVar[DateTimestampPart]
    YEAR: _ClassVar[DateTimestampPart]
    MONTH: _ClassVar[DateTimestampPart]
    DAY: _ClassVar[DateTimestampPart]
    DAYOFWEEK: _ClassVar[DateTimestampPart]
    DAYOFYEAR: _ClassVar[DateTimestampPart]
    QUARTER: _ClassVar[DateTimestampPart]
    HOUR: _ClassVar[DateTimestampPart]
    MINUTE: _ClassVar[DateTimestampPart]
    SECOND: _ClassVar[DateTimestampPart]
    MILLISECOND: _ClassVar[DateTimestampPart]
    MICROSECOND: _ClassVar[DateTimestampPart]
    NANOSECOND: _ClassVar[DateTimestampPart]
    PICOSECOND: _ClassVar[DateTimestampPart]
    DATE: _ClassVar[DateTimestampPart]
    WEEK: _ClassVar[DateTimestampPart]
    DATETIME: _ClassVar[DateTimestampPart]
    TIME: _ClassVar[DateTimestampPart]
    ISOYEAR: _ClassVar[DateTimestampPart]
    ISOWEEK: _ClassVar[DateTimestampPart]
    WEEK_MONDAY: _ClassVar[DateTimestampPart]
    WEEK_TUESDAY: _ClassVar[DateTimestampPart]
    WEEK_WEDNESDAY: _ClassVar[DateTimestampPart]
    WEEK_THURSDAY: _ClassVar[DateTimestampPart]
    WEEK_FRIDAY: _ClassVar[DateTimestampPart]
    WEEK_SATURDAY: _ClassVar[DateTimestampPart]
__DateTimePart__switch_must_have_a_default__: DateTimestampPart
YEAR: DateTimestampPart
MONTH: DateTimestampPart
DAY: DateTimestampPart
DAYOFWEEK: DateTimestampPart
DAYOFYEAR: DateTimestampPart
QUARTER: DateTimestampPart
HOUR: DateTimestampPart
MINUTE: DateTimestampPart
SECOND: DateTimestampPart
MILLISECOND: DateTimestampPart
MICROSECOND: DateTimestampPart
NANOSECOND: DateTimestampPart
PICOSECOND: DateTimestampPart
DATE: DateTimestampPart
WEEK: DateTimestampPart
DATETIME: DateTimestampPart
TIME: DateTimestampPart
ISOYEAR: DateTimestampPart
ISOWEEK: DateTimestampPart
WEEK_MONDAY: DateTimestampPart
WEEK_TUESDAY: DateTimestampPart
WEEK_WEDNESDAY: DateTimestampPart
WEEK_THURSDAY: DateTimestampPart
WEEK_FRIDAY: DateTimestampPart
WEEK_SATURDAY: DateTimestampPart
