# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/resolved_ast_enums.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/resolved_ast_enums.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/resolved_ast/resolved_ast_enums.proto\x12\x07zetasql\"\x96\x01\n\x19ResolvedSubqueryExprEnums\"y\n\x0cSubqueryType\x12\n\n\x06SCALAR\x10\x00\x12\t\n\x05\x41RRAY\x10\x01\x12\n\n\x06\x45XISTS\x10\x02\x12\x06\n\x02IN\x10\x03\x12\x0c\n\x08LIKE_ANY\x10\x04\x12\x0c\n\x08LIKE_ALL\x10\x05\x12\x10\n\x0cNOT_LIKE_ANY\x10\x06\x12\x10\n\x0cNOT_LIKE_ALL\x10\x07\"M\n\x15ResolvedJoinScanEnums\"4\n\x08JoinType\x12\t\n\x05INNER\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\"\xd0\x02\n\x1dResolvedSetOperationScanEnums\"\x85\x01\n\x10SetOperationType\x12\r\n\tUNION_ALL\x10\x00\x12\x12\n\x0eUNION_DISTINCT\x10\x01\x12\x11\n\rINTERSECT_ALL\x10\x02\x12\x16\n\x12INTERSECT_DISTINCT\x10\x03\x12\x0e\n\nEXCEPT_ALL\x10\x04\x12\x13\n\x0f\x45XCEPT_DISTINCT\x10\x05\"W\n\x1bSetOperationColumnMatchMode\x12\x0f\n\x0b\x42Y_POSITION\x10\x00\x12\x11\n\rCORRESPONDING\x10\x01\x12\x14\n\x10\x43ORRESPONDING_BY\x10\x02\"N\n!SetOperationColumnPropagationMode\x12\n\n\x06STRICT\x10\x00\x12\t\n\x05INNER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\"\\\n\x1aResolvedRecursiveScanEnums\">\n\x19RecursiveSetOperationType\x12\r\n\tUNION_ALL\x10\x00\x12\x12\n\x0eUNION_DISTINCT\x10\x01\">\n\x17ResolvedSampleScanEnums\"#\n\nSampleUnit\x12\x08\n\x04ROWS\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\"c\n\x18ResolvedOrderByItemEnums\"G\n\rNullOrderMode\x12\x15\n\x11ORDER_UNSPECIFIED\x10\x00\x12\x0f\n\x0bNULLS_FIRST\x10\x01\x12\x0e\n\nNULLS_LAST\x10\x02\"\xf4\x03\n\x1cResolvedCreateStatementEnums\"_\n\x0b\x43reateScope\x12\x18\n\x14\x43REATE_DEFAULT_SCOPE\x10\x00\x12\x12\n\x0e\x43REATE_PRIVATE\x10\x01\x12\x11\n\rCREATE_PUBLIC\x10\x02\x12\x0f\n\x0b\x43REATE_TEMP\x10\x03\"Q\n\nCreateMode\x12\x12\n\x0e\x43REATE_DEFAULT\x10\x00\x12\x15\n\x11\x43REATE_OR_REPLACE\x10\x01\x12\x18\n\x14\x43REATE_IF_NOT_EXISTS\x10\x02\"_\n\x0bSqlSecurity\x12\x1c\n\x18SQL_SECURITY_UNSPECIFIED\x10\x00\x12\x18\n\x14SQL_SECURITY_DEFINER\x10\x01\x12\x18\n\x14SQL_SECURITY_INVOKER\x10\x02\"\xbe\x01\n\x10\x44\x65terminismLevel\x12\x1b\n\x17\x44\x45TERMINISM_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x45TERMINISM_DETERMINISTIC\x10\x01\x12!\n\x1d\x44\x45TERMINISM_NOT_DETERMINISTIC\x10\x02\x12\x19\n\x15\x44\x45TERMINISM_IMMUTABLE\x10\x03\x12\x16\n\x12\x44\x45TERMINISM_STABLE\x10\x04\x12\x18\n\x14\x44\x45TERMINISM_VOLATILE\x10\x05\"\x8e\x01\n ResolvedGeneratedColumnInfoEnums\"=\n\nStoredMode\x12\x0e\n\nNON_STORED\x10\x00\x12\n\n\x06STORED\x10\x01\x12\x13\n\x0fSTORED_VOLATILE\x10\x02\"+\n\rGeneratedMode\x12\n\n\x06\x41LWAYS\x10\x00\x12\x0e\n\nBY_DEFAULT\x10\x01\"Y\n\x15ResolvedDropStmtEnums\"@\n\x08\x44ropMode\x12\x19\n\x15\x44ROP_MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\"h\n\x16ResolvedBeginStmtEnums\"N\n\rReadWriteMode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_READ_ONLY\x10\x01\x12\x13\n\x0fMODE_READ_WRITE\x10\x02\"<\n\x18ResolvedWindowFrameEnums\" \n\tFrameUnit\x12\x08\n\x04ROWS\x10\x00\x12\t\n\x05RANGE\x10\x01\"\x9d\x01\n\x1cResolvedWindowFrameExprEnums\"}\n\x0c\x42oundaryType\x12\x17\n\x13UNBOUNDED_PRECEDING\x10\x00\x12\x14\n\x10OFFSET_PRECEDING\x10\x01\x12\x0f\n\x0b\x43URRENT_ROW\x10\x02\x12\x14\n\x10OFFSET_FOLLOWING\x10\x03\x12\x17\n\x13UNBOUNDED_FOLLOWING\x10\x04\"c\n\x17ResolvedInsertStmtEnums\"H\n\nInsertMode\x12\x0c\n\x08OR_ERROR\x10\x00\x12\r\n\tOR_IGNORE\x10\x01\x12\x0e\n\nOR_REPLACE\x10\x02\x12\r\n\tOR_UPDATE\x10\x03\"\x9a\x01\n\x16ResolvedMergeWhenEnums\"N\n\tMatchType\x12\x0b\n\x07MATCHED\x10\x00\x12\x19\n\x15NOT_MATCHED_BY_SOURCE\x10\x01\x12\x19\n\x15NOT_MATCHED_BY_TARGET\x10\x02\"0\n\nActionType\x12\n\n\x06INSERT\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\"J\n\x1dResolvedOnConflictClauseEnums\")\n\x0e\x43onflictAction\x12\x0b\n\x07NOTHING\x10\x00\x12\n\n\x06UPDATE\x10\x01\"X\n\x18ResolvedArgumentDefEnums\"<\n\x0c\x41rgumentKind\x12\n\n\x06SCALAR\x10\x00\x12\r\n\tAGGREGATE\x10\x01\x12\x11\n\rNOT_AGGREGATE\x10\x02\"Y\n\x1dResolvedFunctionCallBaseEnums\"8\n\tErrorMode\x12\x16\n\x12\x44\x45\x46\x41ULT_ERROR_MODE\x10\x00\x12\x13\n\x0fSAFE_ERROR_MODE\x10\x01\"\x80\x01\n&ResolvedNonScalarFunctionCallBaseEnums\"V\n\x14NullHandlingModifier\x12\x19\n\x15\x44\x45\x46\x41ULT_NULL_HANDLING\x10\x00\x12\x10\n\x0cIGNORE_NULLS\x10\x01\x12\x11\n\rRESPECT_NULLS\x10\x02\"[\n$ResolvedAggregateHavingModifierEnums\"3\n\x12HavingModifierKind\x12\x0b\n\x07INVALID\x10\x00\x12\x07\n\x03MAX\x10\x01\x12\x07\n\x03MIN\x10\x02\"W\n\x16ResolvedStatementEnums\"=\n\x0cObjectAccess\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x0e\n\nREAD_WRITE\x10\x03\"w\n\x17ResolvedImportStmtEnums\"\\\n\nImportKind\x12\n\n\x06MODULE\x10\x00\x12\t\n\x05PROTO\x10\x01\x12\x37\n*__ImportKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"\x99\x01\n\x17ResolvedForeignKeyEnums\"3\n\tMatchMode\x12\n\n\x06SIMPLE\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x10\n\x0cNOT_DISTINCT\x10\x02\"I\n\x0f\x41\x63tionOperation\x12\r\n\tNO_ACTION\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\x12\x0c\n\x08SET_NULL\x10\x03\"T\n\x1cResolvedAuxLoadDataStmtEnums\"4\n\rInsertionMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41PPEND\x10\x01\x12\r\n\tOVERWRITE\x10\x02\"~\n\x1fResolvedMatchRecognizeScanEnums\"[\n\x12\x41\x66terMatchSkipMode\x12%\n!AFTER_MATCH_SKIP_MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x45ND_OF_MATCH\x10\x01\x12\x0c\n\x08NEXT_ROW\x10\x02\"\\\n(ResolvedMatchRecognizePatternAnchorEnums\"0\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02\"\x8e\x01\n+ResolvedMatchRecognizePatternOperationEnums\"_\n\"MatchRecognizePatternOperationType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x43ONCAT\x10\x01\x12\r\n\tALTERNATE\x10\x02\"q\n\x1fResolvedGraphLabelNaryExprEnums\"N\n\x12GraphLogicalOpType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03NOT\x10\x01\x12\x07\n\x03\x41ND\x10\x02\x12\x06\n\x02OR\x10\x03\"M\n\x1aResolvedGraphEdgeScanEnums\"/\n\x0f\x45\x64geOrientation\x12\x07\n\x03\x41NY\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\"q\n\x1aResolvedGraphPathModeEnums\"S\n\x08PathMode\x12\x19\n\x15PATH_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04WALK\x10\x01\x12\t\n\x05TRAIL\x10\x02\x12\n\n\x06SIMPLE\x10\x03\x12\x0b\n\x07\x41\x43YCLIC\x10\x04\"\x8a\x01\n\"ResolvedGraphPathSearchPrefixEnums\"d\n\x14PathSearchPrefixType\x12\'\n#PATH_SEARCH_PREFIX_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x0c\n\x08SHORTEST\x10\x02\x12\x0c\n\x08\x43HEAPEST\x10\x03\"`\n\x1aResolvedDropIndexStmtEnums\"B\n\tIndexType\x12\x11\n\rINDEX_DEFAULT\x10\x00\x12\x10\n\x0cINDEX_SEARCH\x10\x01\x12\x10\n\x0cINDEX_VECTOR\x10\x02\"Y\n\x13ResolvedOptionEnums\"B\n\x0c\x41ssignmentOp\x12\x12\n\x0e\x44\x45\x46\x41ULT_ASSIGN\x10\x00\x12\x0e\n\nADD_ASSIGN\x10\x01\x12\x0e\n\nSUB_ASSIGN\x10\x02\"7\n\x15ResolvedLockModeEnums\"\x1e\n\x10LockStrengthType\x12\n\n\x06UPDATE\x10\x00\"f\n\x1bResolvedAlterIndexStmtEnums\"G\n\x0e\x41lterIndexType\x12\x11\n\rINDEX_DEFAULT\x10\x00\x12\x10\n\x0cINDEX_SEARCH\x10\x01\x12\x10\n\x0cINDEX_VECTOR\x10\x02\"n\n\x1cResolvedUpdateFieldItemEnums\"N\n\tOperation\x12\x11\n\rUPDATE_SINGLE\x10\x00\x12\x0f\n\x0bUPDATE_MANY\x10\x01\x12\x1d\n\x19UPDATE_SINGLE_NO_CREATION\x10\x02\x42;\n\x1e\x63om.google.zetasql.resolvedastB\x17ZetaSQLResolvedASTEnumsP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.resolved_ast_enums_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.google.zetasql.resolvedastB\027ZetaSQLResolvedASTEnumsP\001'
  _globals['_RESOLVEDSUBQUERYEXPRENUMS']._serialized_start=59
  _globals['_RESOLVEDSUBQUERYEXPRENUMS']._serialized_end=209
  _globals['_RESOLVEDSUBQUERYEXPRENUMS_SUBQUERYTYPE']._serialized_start=88
  _globals['_RESOLVEDSUBQUERYEXPRENUMS_SUBQUERYTYPE']._serialized_end=209
  _globals['_RESOLVEDJOINSCANENUMS']._serialized_start=211
  _globals['_RESOLVEDJOINSCANENUMS']._serialized_end=288
  _globals['_RESOLVEDJOINSCANENUMS_JOINTYPE']._serialized_start=236
  _globals['_RESOLVEDJOINSCANENUMS_JOINTYPE']._serialized_end=288
  _globals['_RESOLVEDSETOPERATIONSCANENUMS']._serialized_start=291
  _globals['_RESOLVEDSETOPERATIONSCANENUMS']._serialized_end=627
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONTYPE']._serialized_start=325
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONTYPE']._serialized_end=458
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNMATCHMODE']._serialized_start=460
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNMATCHMODE']._serialized_end=547
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNPROPAGATIONMODE']._serialized_start=549
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNPROPAGATIONMODE']._serialized_end=627
  _globals['_RESOLVEDRECURSIVESCANENUMS']._serialized_start=629
  _globals['_RESOLVEDRECURSIVESCANENUMS']._serialized_end=721
  _globals['_RESOLVEDRECURSIVESCANENUMS_RECURSIVESETOPERATIONTYPE']._serialized_start=659
  _globals['_RESOLVEDRECURSIVESCANENUMS_RECURSIVESETOPERATIONTYPE']._serialized_end=721
  _globals['_RESOLVEDSAMPLESCANENUMS']._serialized_start=723
  _globals['_RESOLVEDSAMPLESCANENUMS']._serialized_end=785
  _globals['_RESOLVEDSAMPLESCANENUMS_SAMPLEUNIT']._serialized_start=750
  _globals['_RESOLVEDSAMPLESCANENUMS_SAMPLEUNIT']._serialized_end=785
  _globals['_RESOLVEDORDERBYITEMENUMS']._serialized_start=787
  _globals['_RESOLVEDORDERBYITEMENUMS']._serialized_end=886
  _globals['_RESOLVEDORDERBYITEMENUMS_NULLORDERMODE']._serialized_start=815
  _globals['_RESOLVEDORDERBYITEMENUMS_NULLORDERMODE']._serialized_end=886
  _globals['_RESOLVEDCREATESTATEMENTENUMS']._serialized_start=889
  _globals['_RESOLVEDCREATESTATEMENTENUMS']._serialized_end=1389
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATESCOPE']._serialized_start=921
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATESCOPE']._serialized_end=1016
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATEMODE']._serialized_start=1018
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATEMODE']._serialized_end=1099
  _globals['_RESOLVEDCREATESTATEMENTENUMS_SQLSECURITY']._serialized_start=1101
  _globals['_RESOLVEDCREATESTATEMENTENUMS_SQLSECURITY']._serialized_end=1196
  _globals['_RESOLVEDCREATESTATEMENTENUMS_DETERMINISMLEVEL']._serialized_start=1199
  _globals['_RESOLVEDCREATESTATEMENTENUMS_DETERMINISMLEVEL']._serialized_end=1389
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS']._serialized_start=1392
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS']._serialized_end=1534
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_start=1428
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_end=1489
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_start=1491
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_end=1534
  _globals['_RESOLVEDDROPSTMTENUMS']._serialized_start=1536
  _globals['_RESOLVEDDROPSTMTENUMS']._serialized_end=1625
  _globals['_RESOLVEDDROPSTMTENUMS_DROPMODE']._serialized_start=1561
  _globals['_RESOLVEDDROPSTMTENUMS_DROPMODE']._serialized_end=1625
  _globals['_RESOLVEDBEGINSTMTENUMS']._serialized_start=1627
  _globals['_RESOLVEDBEGINSTMTENUMS']._serialized_end=1731
  _globals['_RESOLVEDBEGINSTMTENUMS_READWRITEMODE']._serialized_start=1653
  _globals['_RESOLVEDBEGINSTMTENUMS_READWRITEMODE']._serialized_end=1731
  _globals['_RESOLVEDWINDOWFRAMEENUMS']._serialized_start=1733
  _globals['_RESOLVEDWINDOWFRAMEENUMS']._serialized_end=1793
  _globals['_RESOLVEDWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_start=1761
  _globals['_RESOLVEDWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_end=1793
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS']._serialized_start=1796
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS']._serialized_end=1953
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_start=1828
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_end=1953
  _globals['_RESOLVEDINSERTSTMTENUMS']._serialized_start=1955
  _globals['_RESOLVEDINSERTSTMTENUMS']._serialized_end=2054
  _globals['_RESOLVEDINSERTSTMTENUMS_INSERTMODE']._serialized_start=1982
  _globals['_RESOLVEDINSERTSTMTENUMS_INSERTMODE']._serialized_end=2054
  _globals['_RESOLVEDMERGEWHENENUMS']._serialized_start=2057
  _globals['_RESOLVEDMERGEWHENENUMS']._serialized_end=2211
  _globals['_RESOLVEDMERGEWHENENUMS_MATCHTYPE']._serialized_start=2083
  _globals['_RESOLVEDMERGEWHENENUMS_MATCHTYPE']._serialized_end=2161
  _globals['_RESOLVEDMERGEWHENENUMS_ACTIONTYPE']._serialized_start=2163
  _globals['_RESOLVEDMERGEWHENENUMS_ACTIONTYPE']._serialized_end=2211
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS']._serialized_start=2213
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS']._serialized_end=2287
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_start=2246
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_end=2287
  _globals['_RESOLVEDARGUMENTDEFENUMS']._serialized_start=2289
  _globals['_RESOLVEDARGUMENTDEFENUMS']._serialized_end=2377
  _globals['_RESOLVEDARGUMENTDEFENUMS_ARGUMENTKIND']._serialized_start=2317
  _globals['_RESOLVEDARGUMENTDEFENUMS_ARGUMENTKIND']._serialized_end=2377
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS']._serialized_start=2379
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS']._serialized_end=2468
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS_ERRORMODE']._serialized_start=2412
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS_ERRORMODE']._serialized_end=2468
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS']._serialized_start=2471
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS']._serialized_end=2599
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS_NULLHANDLINGMODIFIER']._serialized_start=2513
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS_NULLHANDLINGMODIFIER']._serialized_end=2599
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS']._serialized_start=2601
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS']._serialized_end=2692
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS_HAVINGMODIFIERKIND']._serialized_start=2641
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS_HAVINGMODIFIERKIND']._serialized_end=2692
  _globals['_RESOLVEDSTATEMENTENUMS']._serialized_start=2694
  _globals['_RESOLVEDSTATEMENTENUMS']._serialized_end=2781
  _globals['_RESOLVEDSTATEMENTENUMS_OBJECTACCESS']._serialized_start=2720
  _globals['_RESOLVEDSTATEMENTENUMS_OBJECTACCESS']._serialized_end=2781
  _globals['_RESOLVEDIMPORTSTMTENUMS']._serialized_start=2783
  _globals['_RESOLVEDIMPORTSTMTENUMS']._serialized_end=2902
  _globals['_RESOLVEDIMPORTSTMTENUMS_IMPORTKIND']._serialized_start=2810
  _globals['_RESOLVEDIMPORTSTMTENUMS_IMPORTKIND']._serialized_end=2902
  _globals['_RESOLVEDFOREIGNKEYENUMS']._serialized_start=2905
  _globals['_RESOLVEDFOREIGNKEYENUMS']._serialized_end=3058
  _globals['_RESOLVEDFOREIGNKEYENUMS_MATCHMODE']._serialized_start=2932
  _globals['_RESOLVEDFOREIGNKEYENUMS_MATCHMODE']._serialized_end=2983
  _globals['_RESOLVEDFOREIGNKEYENUMS_ACTIONOPERATION']._serialized_start=2985
  _globals['_RESOLVEDFOREIGNKEYENUMS_ACTIONOPERATION']._serialized_end=3058
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS']._serialized_start=3060
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS']._serialized_end=3144
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS_INSERTIONMODE']._serialized_start=3092
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS_INSERTIONMODE']._serialized_end=3144
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS']._serialized_start=3146
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS']._serialized_end=3272
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS_AFTERMATCHSKIPMODE']._serialized_start=3181
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS_AFTERMATCHSKIPMODE']._serialized_end=3272
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS']._serialized_start=3274
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS']._serialized_end=3366
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS_MODE']._serialized_start=3318
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS_MODE']._serialized_end=3366
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS']._serialized_start=3369
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS']._serialized_end=3511
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS_MATCHRECOGNIZEPATTERNOPERATIONTYPE']._serialized_start=3416
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS_MATCHRECOGNIZEPATTERNOPERATIONTYPE']._serialized_end=3511
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS']._serialized_start=3513
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS']._serialized_end=3626
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS_GRAPHLOGICALOPTYPE']._serialized_start=3548
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS_GRAPHLOGICALOPTYPE']._serialized_end=3626
  _globals['_RESOLVEDGRAPHEDGESCANENUMS']._serialized_start=3628
  _globals['_RESOLVEDGRAPHEDGESCANENUMS']._serialized_end=3705
  _globals['_RESOLVEDGRAPHEDGESCANENUMS_EDGEORIENTATION']._serialized_start=3658
  _globals['_RESOLVEDGRAPHEDGESCANENUMS_EDGEORIENTATION']._serialized_end=3705
  _globals['_RESOLVEDGRAPHPATHMODEENUMS']._serialized_start=3707
  _globals['_RESOLVEDGRAPHPATHMODEENUMS']._serialized_end=3820
  _globals['_RESOLVEDGRAPHPATHMODEENUMS_PATHMODE']._serialized_start=3737
  _globals['_RESOLVEDGRAPHPATHMODEENUMS_PATHMODE']._serialized_end=3820
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS']._serialized_start=3823
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS']._serialized_end=3961
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_start=3861
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_end=3961
  _globals['_RESOLVEDDROPINDEXSTMTENUMS']._serialized_start=3963
  _globals['_RESOLVEDDROPINDEXSTMTENUMS']._serialized_end=4059
  _globals['_RESOLVEDDROPINDEXSTMTENUMS_INDEXTYPE']._serialized_start=3993
  _globals['_RESOLVEDDROPINDEXSTMTENUMS_INDEXTYPE']._serialized_end=4059
  _globals['_RESOLVEDOPTIONENUMS']._serialized_start=4061
  _globals['_RESOLVEDOPTIONENUMS']._serialized_end=4150
  _globals['_RESOLVEDOPTIONENUMS_ASSIGNMENTOP']._serialized_start=4084
  _globals['_RESOLVEDOPTIONENUMS_ASSIGNMENTOP']._serialized_end=4150
  _globals['_RESOLVEDLOCKMODEENUMS']._serialized_start=4152
  _globals['_RESOLVEDLOCKMODEENUMS']._serialized_end=4207
  _globals['_RESOLVEDLOCKMODEENUMS_LOCKSTRENGTHTYPE']._serialized_start=4177
  _globals['_RESOLVEDLOCKMODEENUMS_LOCKSTRENGTHTYPE']._serialized_end=4207
  _globals['_RESOLVEDALTERINDEXSTMTENUMS']._serialized_start=4209
  _globals['_RESOLVEDALTERINDEXSTMTENUMS']._serialized_end=4311
  _globals['_RESOLVEDALTERINDEXSTMTENUMS_ALTERINDEXTYPE']._serialized_start=4240
  _globals['_RESOLVEDALTERINDEXSTMTENUMS_ALTERINDEXTYPE']._serialized_end=4311
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS']._serialized_start=4313
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS']._serialized_end=4423
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS_OPERATION']._serialized_start=4345
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS_OPERATION']._serialized_end=4423
# @@protoc_insertion_point(module_scope)
