# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/fix_suggestion.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/fix_suggestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as zetasql_dot_public_dot_error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#zetasql/public/fix_suggestion.proto\x12\x07zetasql\x1a#zetasql/public/error_location.proto\"A\n\x08\x46ixRange\x12%\n\x05start\x18\x01 \x01(\x0b\x32\x16.zetasql.ErrorLocation\x12\x0e\n\x06length\x18\x02 \x01(\x05\">\n\x08TextEdit\x12 \n\x05range\x18\x01 \x01(\x0b\x32\x11.zetasql.FixRange\x12\x10\n\x08new_text\x18\x02 \x01(\t\".\n\x05\x45\x64its\x12%\n\ntext_edits\x18\x01 \x03(\x0b\x32\x11.zetasql.TextEdit\"3\n\x03\x46ix\x12\r\n\x05title\x18\x01 \x01(\t\x12\x1d\n\x05\x65\x64its\x18\x02 \x01(\x0b\x32\x0e.zetasql.Edits\"<\n\x13\x45rrorFixSuggestions\x12%\n\x0f\x66ix_suggestions\x18\x01 \x03(\x0b\x32\x0c.zetasql.FixB\x14\n\x12\x63om.google.zetasql')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.fix_suggestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql'
  _globals['_FIXRANGE']._serialized_start=85
  _globals['_FIXRANGE']._serialized_end=150
  _globals['_TEXTEDIT']._serialized_start=152
  _globals['_TEXTEDIT']._serialized_end=214
  _globals['_EDITS']._serialized_start=216
  _globals['_EDITS']._serialized_end=262
  _globals['_FIX']._serialized_start=264
  _globals['_FIX']._serialized_end=315
  _globals['_ERRORFIXSUGGESTIONS']._serialized_start=317
  _globals['_ERRORFIXSUGGESTIONS']._serialized_end=377
# @@protoc_insertion_point(module_scope)
