# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/proto/logging.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/proto/logging.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"zetasql/public/proto/logging.proto\x12\x07zetasql\x1a\x1egoogle/protobuf/duration.proto\"\xfb\x01\n\x0e\x45xecutionStats\x12,\n\twall_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x63pu_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x15stack_available_bytes\x18\x04 \x01(\x04\x12\x1d\n\x15stack_peak_used_bytes\x18\x05 \x01(\x04\"P\n\rParserVariant\x12\x16\n\x12PARSER_UNSPECIFIED\x10\x00\x12\x10\n\x0cPARSER_BISON\x10\x01\x12\x15\n\x11PARSER_TEXTMAPPER\x10\x02\"\xd4\x03\n\x10\x41nalyzerLogEntry\x12\x1a\n\x12num_lexical_tokens\x18\x01 \x01(\x03\x12\x38\n\x17overall_execution_stats\x18\x02 \x01(\x0b\x32\x17.zetasql.ExecutionStats\x12P\n\x15\x65xecution_stats_by_op\x18\x03 \x03(\x0b\x32\x31.zetasql.AnalyzerLogEntry.ExecutionStatsByOpEntry\x1a\x81\x01\n\x17\x45xecutionStatsByOpEntry\x12>\n\x03key\x18\x01 \x01(\x0e\x32\x31.zetasql.AnalyzerLogEntry.LoggedOperationCategory\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.zetasql.ExecutionStats\"\x93\x01\n\x17LoggedOperationCategory\x12%\n!UNKNOWN_LOGGED_OPERATION_CATEGORY\x10\x00\x12\n\n\x06PARSER\x10\x01\x12\x0c\n\x08RESOLVER\x10\x02\x12\x0c\n\x08REWRITER\x10\x03\x12\x14\n\x10\x43\x41TALOG_RESOLVER\x10\x04\x12\r\n\tVALIDATOR\x10\x05\"\x04\x08\x06\x10\x06\x42\x02P\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.proto.logging_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_EXECUTIONSTATS']._serialized_start=80
  _globals['_EXECUTIONSTATS']._serialized_end=331
  _globals['_EXECUTIONSTATS_PARSERVARIANT']._serialized_start=251
  _globals['_EXECUTIONSTATS_PARSERVARIANT']._serialized_end=331
  _globals['_ANALYZERLOGENTRY']._serialized_start=334
  _globals['_ANALYZERLOGENTRY']._serialized_end=802
  _globals['_ANALYZERLOGENTRY_EXECUTIONSTATSBYOPENTRY']._serialized_start=523
  _globals['_ANALYZERLOGENTRY_EXECUTIONSTATSBYOPENTRY']._serialized_end=652
  _globals['_ANALYZERLOGENTRY_LOGGEDOPERATIONCATEGORY']._serialized_start=655
  _globals['_ANALYZERLOGENTRY_LOGGEDOPERATIONCATEGORY']._serialized_end=802
# @@protoc_insertion_point(module_scope)
