# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import simple_value_pb2 as zetasql_dot_public_dot_simple__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fzetasql/public/annotation.proto\x12\x07zetasql\x1a!zetasql/public/simple_value.proto\"G\n\x0f\x41nnotationProto\x12\n\n\x02id\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.zetasql.SimpleValueProto\"\xc0\x01\n\x12\x41nnotationMapProto\x12\x0f\n\x07is_null\x18\x04 \x01(\x08\x12-\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x18.zetasql.AnnotationProto\x12\x36\n\rarray_element\x18\x02 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProtoB\x02\x18\x01\x12\x32\n\rstruct_fields\x18\x03 \x03(\x0b\x32\x1b.zetasql.AnnotationMapProtoB*\n\x12\x63om.google.zetasqlB\x11ZetaSQLAnnotation\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\021ZetaSQLAnnotation\370\001\001'
  _globals['_ANNOTATIONMAPPROTO'].fields_by_name['array_element']._loaded_options = None
  _globals['_ANNOTATIONMAPPROTO'].fields_by_name['array_element']._serialized_options = b'\030\001'
  _globals['_ANNOTATIONPROTO']._serialized_start=79
  _globals['_ANNOTATIONPROTO']._serialized_end=150
  _globals['_ANNOTATIONMAPPROTO']._serialized_start=153
  _globals['_ANNOTATIONMAPPROTO']._serialized_end=345
# @@protoc_insertion_point(module_scope)
