# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/common/match_recognize/match_test_result.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/common/match_recognize/match_test_result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6zetasql/common/match_recognize/match_test_result.proto\x12!zetasql.functions.match_recognize\"4\n\x10MatchResultProto\x12\r\n\x05match\x18\x01 \x03(\t\x12\x11\n\trep_count\x18\x03 \x01(\x05\"\xa8\x01\n\x19MatchPartitionResultProto\x12\x44\n\x07\x61\x64\x64_row\x18\x01 \x03(\x0b\x32\x33.zetasql.functions.match_recognize.MatchResultProto\x12\x45\n\x08\x66inalize\x18\x02 \x01(\x0b\x32\x33.zetasql.functions.match_recognize.MatchResultProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.common.match_recognize.match_test_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MATCHRESULTPROTO']._serialized_start=93
  _globals['_MATCHRESULTPROTO']._serialized_end=145
  _globals['_MATCHPARTITIONRESULTPROTO']._serialized_start=148
  _globals['_MATCHPARTITIONRESULTPROTO']._serialized_end=316
# @@protoc_insertion_point(module_scope)
