# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/proto/wire_format_annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/proto/wire_format_annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1zetasql/public/proto/wire_format_annotation.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\"\n WireFormatAnnotationEmptyMessage*C\n\tTableType\x12\x16\n\x12\x44\x45\x46\x41ULT_TABLE_TYPE\x10\x00\x12\r\n\tSQL_TABLE\x10\x01\x12\x0f\n\x0bVALUE_TABLE\x10\x02:;\n\x11struct_field_name\x12\x1d.google.protobuf.FieldOptions\x18\xd5\xe6\x9b! \x01(\t:6\n\x0cis_raw_proto\x12\x1d.google.protobuf.FieldOptions\x18\x8a\x90\x8bN \x01(\x08:;\n\x10is_hidden_column\x12\x1d.google.protobuf.FieldOptions\x18\xe7\xc1\x93\xa1\x01 \x01(\x08:5\n\nis_measure\x12\x1d.google.protobuf.FieldOptions\x18\xc8\xdd\xbe\xff\x01 \x01(\x08:6\n\nis_wrapper\x12\x1f.google.protobuf.MessageOptions\x18\xe2\xa3\xdb\x17 \x01(\x08:5\n\tis_struct\x12\x1f.google.protobuf.MessageOptions\x18\xc2\x92\xdb\x17 \x01(\x08:J\n\ntable_type\x12\x1f.google.protobuf.MessageOptions\x18\x84\xdf\xb3) \x01(\x0e\x32\x12.zetasql.TableTypeB/\n\x12\x63om.google.zetasqlB\x19WireFormatAnnotationProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.proto.wire_format_annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\031WireFormatAnnotationProto'
  _globals['_TABLETYPE']._serialized_start=132
  _globals['_TABLETYPE']._serialized_end=199
  _globals['_WIREFORMATANNOTATIONEMPTYMESSAGE']._serialized_start=96
  _globals['_WIREFORMATANNOTATIONEMPTYMESSAGE']._serialized_end=130
# @@protoc_insertion_point(module_scope)
