# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/rank_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/rank_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(zetasql/public/functions/rank_type.proto\x12\x11zetasql.functions\x1a\x19zetasql/public/type.proto\"\x97\x01\n\rRankTypeEnums\"\x85\x01\n\x08RankType\x12\x1f\n\x11RANK_TYPE_UNKNOWN\x10\x00\x1a\x08\xb2\xf2\xb0\x92\x0e\x02\x08\x01\x12\x1f\n\x1b\x46RACTION_LESS_THAN_OR_EQUAL\x10\x01\x12\x0c\n\x08MIDPOINT\x10\x02\x12\x16\n\x12\x46RACTION_LESS_THAN\x10\x03\x1a\x11\xb2\xd0\xaf\xfa\r\x0b\n\tRANK_TYPEB/\n\x1c\x63om.google.zetasql.functionsB\x0fZetaSQLRankType')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.rank_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\017ZetaSQLRankType'
  _globals['_RANKTYPEENUMS_RANKTYPE']._loaded_options = None
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_options = b'\262\320\257\372\r\013\n\tRANK_TYPE'
  _globals['_RANKTYPEENUMS_RANKTYPE'].values_by_name["RANK_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_RANKTYPEENUMS_RANKTYPE'].values_by_name["RANK_TYPE_UNKNOWN"]._serialized_options = b'\262\362\260\222\016\002\010\001'
  _globals['_RANKTYPEENUMS']._serialized_start=91
  _globals['_RANKTYPEENUMS']._serialized_end=242
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_start=109
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_end=242
# @@protoc_insertion_point(module_scope)
