# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/module_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/module_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"zetasql/proto/module_options.proto\x12\x07zetasql\"\xb1\x02\n\x10PerModuleOptions\x12\x1a\n\x12udf_server_address\x18\x01 \x01(\t\x12\x15\n\rudf_namespace\x18\x04 \x01(\t\x12i\n\x16udf_server_import_mode\x18\x02 \x01(\x0e\x32-.zetasql.PerModuleOptions.UdfServerImportMode:\x1aSERVER_ADDRESS_FROM_MODULE\x12\x1a\n\x12udf_scaling_factor\x18\x03 \x01(\x01\"c\n\x13UdfServerImportMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1e\n\x1aSERVER_ADDRESS_FROM_MODULE\x10\x01\x12\x13\n\x0f\x43\x41LLER_PROVIDED\x10\x02\x12\n\n\x06MANUAL\x10\x03\"\xe0\x01\n\rModuleOptions\x12\x31\n\x0eglobal_options\x18\x01 \x01(\x0b\x32\x19.zetasql.PerModuleOptions\x12H\n\x12per_module_options\x18\x02 \x03(\x0b\x32,.zetasql.ModuleOptions.PerModuleOptionsEntry\x1aR\n\x15PerModuleOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.zetasql.PerModuleOptions:\x02\x38\x01\x42\x02P\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.module_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._loaded_options = None
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_PERMODULEOPTIONS']._serialized_start=48
  _globals['_PERMODULEOPTIONS']._serialized_end=353
  _globals['_PERMODULEOPTIONS_UDFSERVERIMPORTMODE']._serialized_start=254
  _globals['_PERMODULEOPTIONS_UDFSERVERIMPORTMODE']._serialized_end=353
  _globals['_MODULEOPTIONS']._serialized_start=356
  _globals['_MODULEOPTIONS']._serialized_end=580
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_start=498
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_end=580
# @@protoc_insertion_point(module_scope)
