# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/formatter_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/formatter_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&zetasql/public/formatter_options.proto\x12\x07zetasql\"\xd5\x02\n\x15\x46ormatterOptionsProto\x12\x15\n\rnew_line_type\x18\x01 \x01(\t\x12\x19\n\x11line_length_limit\x18\x02 \x01(\x05\x12\x1a\n\x12indentation_spaces\x18\x03 \x01(\x05\x12\x1c\n\x14\x61llow_invalid_tokens\x18\x04 \x01(\x08\x12\x1b\n\x13\x63\x61pitalize_keywords\x18\x05 \x01(\x08\x12\x1c\n\x14preserve_line_breaks\x18\x06 \x01(\x08\x12\x1c\n\x14\x65xpand_format_ranges\x18\x07 \x01(\x08\x12\x1d\n\x15\x65nforce_single_quotes\x18\x08 \x01(\x08\x12\x1c\n\x14\x63\x61pitalize_functions\x18\t \x01(\x08\x12!\n\x19\x66ormat_structured_strings\x18\n \x01(\x08\x12\x17\n\x0f\x66ormat_comments\x18\x0b \x01(\x08\"1\n\x13\x46ormatterRangeProto\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\x42\x14\n\x12\x63om.google.zetasql')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.formatter_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql'
  _globals['_FORMATTEROPTIONSPROTO']._serialized_start=52
  _globals['_FORMATTEROPTIONSPROTO']._serialized_end=393
  _globals['_FORMATTERRANGEPROTO']._serialized_start=395
  _globals['_FORMATTERRANGEPROTO']._serialized_end=444
# @@protoc_insertion_point(module_scope)
