# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/information_schema/property_graph.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/information_schema/property_graph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6zetasql/public/information_schema/property_graph.proto\x12\x07zetasql\"\xa7\x02\n\x12PropertyGraphProto\x12\x0f\n\x07\x63\x61talog\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x34\n\x0bnode_tables\x18\x04 \x03(\x0b\x32\x1f.zetasql.GraphElementTableProto\x12\x34\n\x0b\x65\x64ge_tables\x18\x05 \x03(\x0b\x32\x1f.zetasql.GraphElementTableProto\x12/\n\x06labels\x18\x06 \x03(\x0b\x32\x1f.zetasql.GraphElementLabelProto\x12\x45\n\x15property_declarations\x18\x07 \x03(\x0b\x32&.zetasql.GraphPropertyDeclarationProto\"\x8d\x04\n\x16GraphElementTableProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x04kind\x18\x02 \x01(\x0e\x32$.zetasql.GraphElementTableProto.Kind\x12\x19\n\x11\x62\x61se_catalog_name\x18\x03 \x01(\t\x12\x18\n\x10\x62\x61se_schema_name\x18\x04 \x01(\t\x12\x17\n\x0f\x62\x61se_table_name\x18\x05 \x01(\t\x12\x13\n\x0bkey_columns\x18\x06 \x03(\t\x12\x13\n\x0blabel_names\x18\x07 \x03(\t\x12\x43\n\x14property_definitions\x18\x08 \x03(\x0b\x32%.zetasql.GraphPropertyDefinitionProto\x12\x1a\n\x12\x64ynamic_label_expr\x18\x0b \x01(\t\x12\x1d\n\x15\x64ynamic_property_expr\x18\x0c \x01(\t\x12@\n\x11source_node_table\x18\t \x01(\x0b\x32%.zetasql.GraphNodeTableReferenceProto\x12\x45\n\x16\x64\x65stination_node_table\x18\n \x01(\x0b\x32%.zetasql.GraphNodeTableReferenceProto\"0\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x08\n\x04NODE\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\"o\n\x1cGraphNodeTableReferenceProto\x12\x17\n\x0fnode_table_name\x18\x01 \x01(\t\x12\x1a\n\x12\x65\x64ge_table_columns\x18\x02 \x03(\t\x12\x1a\n\x12node_table_columns\x18\x03 \x03(\t\"J\n\x16GraphElementLabelProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x1aproperty_declaration_names\x18\x02 \x03(\t\";\n\x1dGraphPropertyDeclarationProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"_\n\x1cGraphPropertyDefinitionProto\x12!\n\x19property_declaration_name\x18\x01 \x01(\t\x12\x1c\n\x14value_expression_sql\x18\x02 \x01(\tB)\n\x12\x63om.google.zetasqlB\x13PropertyGraphProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.information_schema.property_graph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\023PropertyGraphProtos'
  _globals['_PROPERTYGRAPHPROTO']._serialized_start=68
  _globals['_PROPERTYGRAPHPROTO']._serialized_end=363
  _globals['_GRAPHELEMENTTABLEPROTO']._serialized_start=366
  _globals['_GRAPHELEMENTTABLEPROTO']._serialized_end=891
  _globals['_GRAPHELEMENTTABLEPROTO_KIND']._serialized_start=843
  _globals['_GRAPHELEMENTTABLEPROTO_KIND']._serialized_end=891
  _globals['_GRAPHNODETABLEREFERENCEPROTO']._serialized_start=893
  _globals['_GRAPHNODETABLEREFERENCEPROTO']._serialized_end=1004
  _globals['_GRAPHELEMENTLABELPROTO']._serialized_start=1006
  _globals['_GRAPHELEMENTLABELPROTO']._serialized_end=1080
  _globals['_GRAPHPROPERTYDECLARATIONPROTO']._serialized_start=1082
  _globals['_GRAPHPROPERTYDECLARATIONPROTO']._serialized_end=1141
  _globals['_GRAPHPROPERTYDEFINITIONPROTO']._serialized_start=1143
  _globals['_GRAPHPROPERTYDEFINITIONPROTO']._serialized_end=1238
# @@protoc_insertion_point(module_scope)
