# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/value.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1azetasql/public/value.proto\x12\x07zetasql\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf7\n\n\nValueProto\x12\x15\n\x0bint32_value\x18\x01 \x01(\x05H\x00\x12\x15\n\x0bint64_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0cuint32_value\x18\x03 \x01(\rH\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x14\n\nbool_value\x18\x05 \x01(\x08H\x00\x12\x15\n\x0b\x66loat_value\x18\x06 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x07 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x08 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\t \x01(\x0cH\x00\x12\x14\n\ndate_value\x18\n \x01(\x05H\x00\x12\x14\n\nenum_value\x18\x0c \x01(\x05H\x00\x12\x30\n\x0b\x61rray_value\x18\r \x01(\x0b\x32\x19.zetasql.ValueProto.ArrayH\x00\x12\x32\n\x0cstruct_value\x18\x0e \x01(\x0b\x32\x1a.zetasql.ValueProto.StructH\x00\x12\x19\n\x0bproto_value\x18\x0f \x01(\x0c\x42\x02\x08\x01H\x00\x12\x35\n\x0ftimestamp_value\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\"\n\x14timestamp_pico_value\x18\x1d \x01(\x0c\x42\x02\x18\x01H\x00\x12\x43\n\x15timestamp_picos_value\x18\x1e \x01(\x0b\x32\".zetasql.ValueProto.TimestampPicosH\x00\x12\x36\n\x0e\x64\x61tetime_value\x18\x11 \x01(\x0b\x32\x1c.zetasql.ValueProto.DatetimeH\x00\x12\x14\n\ntime_value\x18\x12 \x01(\x03H\x00\x12\x19\n\x0fgeography_value\x18\x13 \x01(\x0cH\x00\x12\x17\n\rnumeric_value\x18\x14 \x01(\x0cH\x00\x12\x1a\n\x10\x62ignumeric_value\x18\x15 \x01(\x0cH\x00\x12\x14\n\njson_value\x18\x17 \x01(\tH\x00\x12\x18\n\x0einterval_value\x18\x18 \x01(\x0cH\x00\x12\x19\n\x0ftokenlist_value\x18\x19 \x01(\x0cH\x00\x12\x30\n\x0brange_value\x18\x1a \x01(\x0b\x32\x19.zetasql.ValueProto.RangeH\x00\x12\x14\n\nuuid_value\x18\x1b \x01(\x0cH\x00\x12,\n\tmap_value\x18\x1c \x01(\x0b\x32\x17.zetasql.ValueProto.MapH\x00\x12\x33\n(__ValueProto__switch_must_have_a_default\x18\xff\x01 \x01(\x08H\x00\x1a-\n\x05\x41rray\x12$\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x13.zetasql.ValueProto\x1a,\n\x06Struct\x12\"\n\x05\x66ield\x18\x01 \x03(\x0b\x32\x13.zetasql.ValueProto\x1a=\n\x08\x44\x61tetime\x12\"\n\x1a\x62it_field_datetime_seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\x1aM\n\x05Range\x12\"\n\x05start\x18\x01 \x01(\x0b\x32\x13.zetasql.ValueProto\x12 \n\x03\x65nd\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProto\x1aP\n\x08MapEntry\x12 \n\x03key\x18\x01 \x01(\x0b\x32\x13.zetasql.ValueProto\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProto\x1a\x32\n\x03Map\x12+\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x1c.zetasql.ValueProto.MapEntry\x1a\x30\n\x0eTimestampPicos\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05picos\x18\x02 \x01(\x03\x42\x07\n\x05valueJ\x04\x08\x0b\x10\x0cJ\x04\x08\x16\x10\x17\x42%\n\x12\x63om.google.zetasqlB\x0cZetaSQLValue\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\014ZetaSQLValue\370\001\001'
  _globals['_VALUEPROTO'].fields_by_name['proto_value']._loaded_options = None
  _globals['_VALUEPROTO'].fields_by_name['proto_value']._serialized_options = b'\010\001'
  _globals['_VALUEPROTO'].fields_by_name['timestamp_pico_value']._loaded_options = None
  _globals['_VALUEPROTO'].fields_by_name['timestamp_pico_value']._serialized_options = b'\030\001'
  _globals['_VALUEPROTO']._serialized_start=73
  _globals['_VALUEPROTO']._serialized_end=1472
  _globals['_VALUEPROTO_ARRAY']._serialized_start=1034
  _globals['_VALUEPROTO_ARRAY']._serialized_end=1079
  _globals['_VALUEPROTO_STRUCT']._serialized_start=1081
  _globals['_VALUEPROTO_STRUCT']._serialized_end=1125
  _globals['_VALUEPROTO_DATETIME']._serialized_start=1127
  _globals['_VALUEPROTO_DATETIME']._serialized_end=1188
  _globals['_VALUEPROTO_RANGE']._serialized_start=1190
  _globals['_VALUEPROTO_RANGE']._serialized_end=1267
  _globals['_VALUEPROTO_MAPENTRY']._serialized_start=1269
  _globals['_VALUEPROTO_MAPENTRY']._serialized_end=1349
  _globals['_VALUEPROTO_MAP']._serialized_start=1351
  _globals['_VALUEPROTO_MAP']._serialized_end=1401
  _globals['_VALUEPROTO_TIMESTAMPPICOS']._serialized_start=1403
  _globals['_VALUEPROTO_TIMESTAMPPICOS']._serialized_end=1451
# @@protoc_insertion_point(module_scope)
