# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/parser/ast_enums.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/parser/ast_enums.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ezetasql/parser/ast_enums.proto\x12\x07zetasql\"\x9d\x02\n\x18\x41STBinaryExpressionEnums\"\x80\x02\n\x02Op\x12\x0b\n\x07NOT_SET\x10\x00\x12\x08\n\x04LIKE\x10\x01\x12\x06\n\x02IS\x10\x02\x12\x06\n\x02\x45Q\x10\x03\x12\x06\n\x02NE\x10\x04\x12\x07\n\x03NE2\x10\x05\x12\x06\n\x02GT\x10\x06\x12\x06\n\x02LT\x10\x07\x12\x06\n\x02GE\x10\x08\x12\x06\n\x02LE\x10\t\x12\x0e\n\nBITWISE_OR\x10\n\x12\x0f\n\x0b\x42ITWISE_XOR\x10\x0b\x12\x0f\n\x0b\x42ITWISE_AND\x10\x0c\x12\x08\n\x04PLUS\x10\r\x12\t\n\x05MINUS\x10\x0e\x12\x0c\n\x08MULTIPLY\x10\x0f\x12\n\n\x06\x44IVIDE\x10\x10\x12\r\n\tCONCAT_OP\x10\x11\x12\x0c\n\x08\x44ISTINCT\x10\x12\x12\x12\n\x0eIS_SOURCE_NODE\x10\x13\x12\x10\n\x0cIS_DEST_NODE\x10\x14\"_\n\x14\x41STOptionsEntryEnums\"G\n\x0c\x41ssignmentOp\x12\x0b\n\x07NOT_SET\x10\x00\x12\n\n\x06\x41SSIGN\x10\x01\x12\x0e\n\nADD_ASSIGN\x10\x02\x12\x0e\n\nSUB_ASSIGN\x10\x03\"]\n\x1a\x41STOrderingExpressionEnums\"?\n\x0cOrderingSpec\x12\x0b\n\x07NOT_SET\x10\x00\x12\x07\n\x03\x41SC\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\x12\x0f\n\x0bUNSPECIFIED\x10\x03\"\xa5\x01\n\x0c\x41STJoinEnums\"a\n\x08JoinType\x12\x15\n\x11\x44\x45\x46\x41ULT_JOIN_TYPE\x10\x00\x12\t\n\x05\x43OMMA\x10\x01\x12\t\n\x05\x43ROSS\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\x12\t\n\x05INNER\x10\x04\x12\x08\n\x04LEFT\x10\x05\x12\t\n\x05RIGHT\x10\x06\"2\n\x08JoinHint\x12\x10\n\x0cNO_JOIN_HINT\x10\x00\x12\x08\n\x04HASH\x10\x01\x12\n\n\x06LOOKUP\x10\x02\"O\n\x10\x41STSelectAsEnums\";\n\x06\x41sMode\x12\x0b\n\x07NOT_SET\x10\x00\x12\n\n\x06STRUCT\x10\x01\x12\t\n\x05VALUE\x10\x02\x12\r\n\tTYPE_NAME\x10\x03\"n\n\x14\x41STFunctionCallEnums\"V\n\x14NullHandlingModifier\x12\x19\n\x15\x44\x45\x46\x41ULT_NULL_HANDLING\x10\x00\x12\x10\n\x0cIGNORE_NULLS\x10\x01\x12\x11\n\rRESPECT_NULLS\x10\x02\"T\n\x1a\x41STExpressionSubqueryEnums\"6\n\x08Modifier\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x41RRAY\x10\x01\x12\n\n\x06\x45XISTS\x10\x02\x12\t\n\x05VALUE\x10\x03\"G\n\x16\x41STHavingModifierEnums\"-\n\x0cModifierKind\x12\x0b\n\x07NOT_SET\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\"\xcd\x02\n\x14\x41STSetOperationEnums\"B\n\rOperationType\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05UNION\x10\x01\x12\n\n\x06\x45XCEPT\x10\x02\x12\r\n\tINTERSECT\x10\x04\"C\n\rAllOrDistinct\x12\x1b\n\x17\x41LL_OR_DISTINCT_NOT_SET\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0c\n\x08\x44ISTINCT\x10\x02\"h\n\x0f\x43olumnMatchMode\x12\x0f\n\x0b\x42Y_POSITION\x10\x01\x12\x11\n\rCORRESPONDING\x10\x02\x12\x14\n\x10\x43ORRESPONDING_BY\x10\x03\x12\x0b\n\x07\x42Y_NAME\x10\x04\x12\x0e\n\nBY_NAME_ON\x10\x05\"B\n\x15\x43olumnPropagationMode\x12\n\n\x06STRICT\x10\x01\x12\t\n\x05INNER\x10\x02\x12\x08\n\x04LEFT\x10\x03\x12\x08\n\x04\x46ULL\x10\x04\"\x7f\n\x17\x41STUnaryExpressionEnums\"d\n\x02Op\x12\x0b\n\x07NOT_SET\x10\x00\x12\x07\n\x03NOT\x10\x01\x12\x0f\n\x0b\x42ITWISE_NOT\x10\x02\x12\t\n\x05MINUS\x10\x03\x12\x08\n\x04PLUS\x10\x04\x12\x0e\n\nIS_UNKNOWN\x10\x05\x12\x12\n\x0eIS_NOT_UNKNOWN\x10\x06\"7\n\x13\x41STWindowFrameEnums\" \n\tFrameUnit\x12\x08\n\x04ROWS\x10\x01\x12\t\n\x05RANGE\x10\x02\"\x98\x01\n\x17\x41STWindowFrameExprEnums\"}\n\x0c\x42oundaryType\x12\x17\n\x13UNBOUNDED_PRECEDING\x10\x01\x12\x14\n\x10OFFSET_PRECEDING\x10\x02\x12\x0f\n\x0b\x43URRENT_ROW\x10\x03\x12\x14\n\x10OFFSET_FOLLOWING\x10\x04\x12\x17\n\x13UNBOUNDED_FOLLOWING\x10\x05\"O\n\x14\x41STAnySomeAllOpEnums\"7\n\x02Op\x12\x12\n\x0ekUninitialized\x10\x01\x12\x08\n\x04kAny\x10\x02\x12\t\n\x05kSome\x10\x03\x12\x08\n\x04kAll\x10\x04\"V\n ASTTransactionReadWriteModeEnums\"2\n\x04Mode\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\">\n\x17\x41STImportStatementEnums\"#\n\nImportKind\x12\n\n\x06MODULE\x10\x01\x12\t\n\x05PROTO\x10\x02\"S\n\x15\x41STUnpivotClauseEnums\":\n\nNullFilter\x12\x10\n\x0ckUnspecified\x10\x01\x12\x0c\n\x08kInclude\x10\x02\x12\x0c\n\x08kExclude\x10\x03\"\xbe\x01\n\x17\x41STCreateStatementEnums\"B\n\x05Scope\x12\x11\n\rDEFAULT_SCOPE\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\n\n\x06PUBLIC\x10\x02\x12\r\n\tTEMPORARY\x10\x03\"_\n\x0bSqlSecurity\x12\x1c\n\x18SQL_SECURITY_UNSPECIFIED\x10\x00\x12\x18\n\x14SQL_SECURITY_DEFINER\x10\x01\x12\x18\n\x14SQL_SECURITY_INVOKER\x10\x02\"^\n\x19\x41STFunctionParameterEnums\"A\n\x16ProcedureParameterMode\x12\x0b\n\x07NOT_SET\x10\x00\x12\x06\n\x02IN\x10\x01\x12\x07\n\x03OUT\x10\x02\x12\t\n\x05INOUT\x10\x03\"\xa1\x01\n\x1e\x41STTemplatedParameterTypeEnums\"\x7f\n\x11TemplatedTypeKind\x12\x11\n\rUNINITIALIZED\x10\x01\x12\x0c\n\x08\x41NY_TYPE\x10\x02\x12\r\n\tANY_PROTO\x10\x03\x12\x0c\n\x08\x41NY_ENUM\x10\x04\x12\x0e\n\nANY_STRUCT\x10\x05\x12\r\n\tANY_ARRAY\x10\x06\x12\r\n\tANY_TABLE\x10\x07\"\x89\x01\n\x1b\x41STGeneratedColumnInfoEnums\"=\n\nStoredMode\x12\x0e\n\nNON_STORED\x10\x00\x12\n\n\x06STORED\x10\x01\x12\x13\n\x0fSTORED_VOLATILE\x10\x02\"+\n\rGeneratedMode\x12\n\n\x06\x41LWAYS\x10\x00\x12\x0e\n\nBY_DEFAULT\x10\x01\"N\n\x16\x41STColumnPositionEnums\"4\n\x14RelativePositionType\x12\r\n\tPRECEDING\x10\x01\x12\r\n\tFOLLOWING\x10\x02\"\xdc\x01\n\x17\x41STInsertStatementEnums\"C\n\nInsertMode\x12\x10\n\x0c\x44\x45\x46\x41ULT_MODE\x10\x00\x12\x0b\n\x07REPLACE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06IGNORE\x10\x03\"|\n\rParseProgress\x12\x0c\n\x08kInitial\x10\x01\x12\x1e\n\x1akSeenOrIgnoreReplaceUpdate\x10\x02\x12\x13\n\x0fkSeenTargetPath\x10\x03\x12\x13\n\x0fkSeenColumnList\x10\x04\x12\x13\n\x0fkSeenValuesList\x10\x05\"R\n\x18\x41STOnConflictClauseEnums\"6\n\x0e\x43onflictAction\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07NOTHING\x10\x01\x12\n\n\x06UPDATE\x10\x02\"T\n\x13\x41STMergeActionEnums\"=\n\nActionType\x12\x0b\n\x07NOT_SET\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"v\n\x17\x41STMergeWhenClauseEnums\"[\n\tMatchType\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07MATCHED\x10\x01\x12\x19\n\x15NOT_MATCHED_BY_SOURCE\x10\x02\x12\x19\n\x15NOT_MATCHED_BY_TARGET\x10\x03\"N\n\x17\x41STFilterFieldsArgEnums\"3\n\nFilterType\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\x12\x0b\n\x07\x45XCLUDE\x10\x02\"@\n\x12\x41STSampleSizeEnums\"*\n\x04Unit\x12\x0b\n\x07NOT_SET\x10\x00\x12\x08\n\x04ROWS\x10\x01\x12\x0b\n\x07PERCENT\x10\x02\"]\n\x19\x41STForeignKeyActionsEnums\"@\n\x06\x41\x63tion\x12\r\n\tNO_ACTION\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\x12\x0c\n\x08SET_NULL\x10\x03\"N\n\x1b\x41STForeignKeyReferenceEnums\"/\n\x05Match\x12\n\n\x06SIMPLE\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x12\x10\n\x0cNOT_DISTINCT\x10\x03\"i\n\x1e\x41STBreakContinueStatementEnums\"G\n\x14\x42reakContinueKeyword\x12\t\n\x05\x42REAK\x10\x01\x12\t\n\x05LEAVE\x10\x02\x12\x0c\n\x08\x43ONTINUE\x10\x03\x12\x0b\n\x07ITERATE\x10\x04\"Y\n\x15\x41STDropStatementEnums\"@\n\x08\x44ropMode\x12\x19\n\x15\x44ROP_MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\"\xa5\x01\n\x1e\x41STCreateFunctionStmtBaseEnums\"\x82\x01\n\x10\x44\x65terminismLevel\x12\x1b\n\x17\x44\x45TERMINISM_UNSPECIFIED\x10\x00\x12\x11\n\rDETERMINISTIC\x10\x01\x12\x15\n\x11NOT_DETERMINISTIC\x10\x02\x12\r\n\tIMMUTABLE\x10\x03\x12\n\n\x06STABLE\x10\x04\x12\x0c\n\x08VOLATILE\x10\x05\"W\n\x1c\x41STAuxLoadDataStatementEnums\"7\n\rInsertionMode\x12\x0b\n\x07NOT_SET\x10\x00\x12\n\n\x06\x41PPEND\x10\x01\x12\r\n\tOVERWRITE\x10\x02\"M\n\x1f\x41STSpannerInterleaveClauseEnums\"*\n\x04Type\x12\x0b\n\x07NOT_SET\x10\x00\x12\x06\n\x02IN\x10\x01\x12\r\n\tIN_PARENT\x10\x02\"\x87\x01\n\x1c\x41STAfterMatchSkipClauseEnums\"g\n\x18\x41\x66terMatchSkipTargetType\x12\'\n#AFTER_MATCH_SKIP_TARGET_UNSPECIFIED\x10\x00\x12\x11\n\rPAST_LAST_ROW\x10\x01\x12\x0f\n\x0bTO_NEXT_ROW\x10\x02\"P\n\x18\x41STRowPatternAnchorEnums\"4\n\x06\x41nchor\x12\x16\n\x12\x41NCHOR_UNSPECIFIED\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02\"\x83\x01\n\x1b\x41STRowPatternOperationEnums\"d\n\rOperationType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x43ONCAT\x10\x01\x12\r\n\tALTERNATE\x10\x02\x12\x0b\n\x07PERMUTE\x10\x03\x12\x0b\n\x07\x45XCLUDE\x10\x04\"c\n\x18\x41STSymbolQuantifierEnums\"G\n\x06Symbol\x12\x16\n\x12SYMBOL_UNSPECIFIED\x10\x00\x12\x11\n\rQUESTION_MARK\x10\x01\x12\x08\n\x04PLUS\x10\x02\x12\x08\n\x04STAR\x10\x03\"x\n\x1f\x41STGraphNodeTableReferenceEnums\"U\n\x11NodeReferenceType\x12#\n\x1fNODE_REFERENCE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SOURCE\x10\x01\x12\x0f\n\x0b\x44\x45STINATION\x10\x02\"h\n\x1b\x41STGraphLabelOperationEnums\"I\n\rOperationType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03NOT\x10\x01\x12\x07\n\x03\x41ND\x10\x02\x12\x06\n\x02OR\x10\x03\"i\n\x18\x41STGraphEdgePatternEnums\"M\n\x0f\x45\x64geOrientation\x12\x1c\n\x18\x45\x44GE_ORIENTATION_NOT_SET\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\"l\n\x15\x41STGraphPathModeEnums\"S\n\x08PathMode\x12\x19\n\x15PATH_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04WALK\x10\x01\x12\t\n\x05TRAIL\x10\x02\x12\n\n\x06SIMPLE\x10\x03\x12\x0b\n\x07\x41\x43YCLIC\x10\x04\"\xb3\x01\n\x1d\x41STGraphPathSearchPrefixEnums\"\x91\x01\n\x14PathSearchPrefixType\x12\'\n#PATH_SEARCH_PREFIX_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x0c\n\x08SHORTEST\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x12\x10\n\x0c\x41LL_SHORTEST\x10\x04\x12\x0c\n\x08\x43HEAPEST\x10\x05\x12\x10\n\x0c\x41LL_CHEAPEST\x10\x06\"?\n\x10\x41STLockModeEnums\"+\n\x10LockStrengthSpec\x12\x0b\n\x07NOT_SET\x10\x00\x12\n\n\x06UPDATE\x10\x01\"n\n\x1c\x41STBracedConstructorLhsEnums\"N\n\tOperation\x12\x11\n\rUPDATE_SINGLE\x10\x00\x12\x0f\n\x0bUPDATE_MANY\x10\x01\x12\x1d\n\x19UPDATE_SINGLE_NO_CREATION\x10\x02\"a\n\x1b\x41STAlterIndexStatementEnums\"B\n\tIndexType\x12\x11\n\rINDEX_DEFAULT\x10\x00\x12\x10\n\x0cINDEX_SEARCH\x10\x01\x12\x10\n\x0cINDEX_VECTOR\x10\x02*\xad\x03\n\x10SchemaObjectKind\x12=\n0__SchemaObjectKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1c\n\x18kInvalidSchemaObjectKind\x10\x01\x12\x16\n\x12kAggregateFunction\x10\x02\x12\x0f\n\x0bkApproxView\x10\x11\x12\x0f\n\x0bkConnection\x10\x13\x12\r\n\tkConstant\x10\x03\x12\r\n\tkDatabase\x10\x04\x12\x12\n\x0ekExternalTable\x10\x05\x12\r\n\tkFunction\x10\x06\x12\n\n\x06kIndex\x10\x07\x12\x15\n\x11kMaterializedView\x10\x08\x12\n\n\x06kModel\x10\t\x12\x0e\n\nkProcedure\x10\n\x12\x0b\n\x07kSchema\x10\x0b\x12\n\n\x06kTable\x10\x0c\x12\x12\n\x0ekTableFunction\x10\r\x12\t\n\x05kView\x10\x0e\x12\x12\n\x0ekSnapshotTable\x10\x0f\x12\x12\n\x0ekPropertyGraph\x10\x10\x12\x13\n\x0fkExternalSchema\x10\x12\x12\r\n\tkSequence\x10\x14\x42\x1d\n\x19\x63om.google.zetasql.parserP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.parser.ast_enums_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.google.zetasql.parserP\001'
  _globals['_SCHEMAOBJECTKIND']._serialized_start=5438
  _globals['_SCHEMAOBJECTKIND']._serialized_end=5867
  _globals['_ASTBINARYEXPRESSIONENUMS']._serialized_start=44
  _globals['_ASTBINARYEXPRESSIONENUMS']._serialized_end=329
  _globals['_ASTBINARYEXPRESSIONENUMS_OP']._serialized_start=73
  _globals['_ASTBINARYEXPRESSIONENUMS_OP']._serialized_end=329
  _globals['_ASTOPTIONSENTRYENUMS']._serialized_start=331
  _globals['_ASTOPTIONSENTRYENUMS']._serialized_end=426
  _globals['_ASTOPTIONSENTRYENUMS_ASSIGNMENTOP']._serialized_start=355
  _globals['_ASTOPTIONSENTRYENUMS_ASSIGNMENTOP']._serialized_end=426
  _globals['_ASTORDERINGEXPRESSIONENUMS']._serialized_start=428
  _globals['_ASTORDERINGEXPRESSIONENUMS']._serialized_end=521
  _globals['_ASTORDERINGEXPRESSIONENUMS_ORDERINGSPEC']._serialized_start=458
  _globals['_ASTORDERINGEXPRESSIONENUMS_ORDERINGSPEC']._serialized_end=521
  _globals['_ASTJOINENUMS']._serialized_start=524
  _globals['_ASTJOINENUMS']._serialized_end=689
  _globals['_ASTJOINENUMS_JOINTYPE']._serialized_start=540
  _globals['_ASTJOINENUMS_JOINTYPE']._serialized_end=637
  _globals['_ASTJOINENUMS_JOINHINT']._serialized_start=639
  _globals['_ASTJOINENUMS_JOINHINT']._serialized_end=689
  _globals['_ASTSELECTASENUMS']._serialized_start=691
  _globals['_ASTSELECTASENUMS']._serialized_end=770
  _globals['_ASTSELECTASENUMS_ASMODE']._serialized_start=711
  _globals['_ASTSELECTASENUMS_ASMODE']._serialized_end=770
  _globals['_ASTFUNCTIONCALLENUMS']._serialized_start=772
  _globals['_ASTFUNCTIONCALLENUMS']._serialized_end=882
  _globals['_ASTFUNCTIONCALLENUMS_NULLHANDLINGMODIFIER']._serialized_start=796
  _globals['_ASTFUNCTIONCALLENUMS_NULLHANDLINGMODIFIER']._serialized_end=882
  _globals['_ASTEXPRESSIONSUBQUERYENUMS']._serialized_start=884
  _globals['_ASTEXPRESSIONSUBQUERYENUMS']._serialized_end=968
  _globals['_ASTEXPRESSIONSUBQUERYENUMS_MODIFIER']._serialized_start=914
  _globals['_ASTEXPRESSIONSUBQUERYENUMS_MODIFIER']._serialized_end=968
  _globals['_ASTHAVINGMODIFIERENUMS']._serialized_start=970
  _globals['_ASTHAVINGMODIFIERENUMS']._serialized_end=1041
  _globals['_ASTHAVINGMODIFIERENUMS_MODIFIERKIND']._serialized_start=996
  _globals['_ASTHAVINGMODIFIERENUMS_MODIFIERKIND']._serialized_end=1041
  _globals['_ASTSETOPERATIONENUMS']._serialized_start=1044
  _globals['_ASTSETOPERATIONENUMS']._serialized_end=1377
  _globals['_ASTSETOPERATIONENUMS_OPERATIONTYPE']._serialized_start=1068
  _globals['_ASTSETOPERATIONENUMS_OPERATIONTYPE']._serialized_end=1134
  _globals['_ASTSETOPERATIONENUMS_ALLORDISTINCT']._serialized_start=1136
  _globals['_ASTSETOPERATIONENUMS_ALLORDISTINCT']._serialized_end=1203
  _globals['_ASTSETOPERATIONENUMS_COLUMNMATCHMODE']._serialized_start=1205
  _globals['_ASTSETOPERATIONENUMS_COLUMNMATCHMODE']._serialized_end=1309
  _globals['_ASTSETOPERATIONENUMS_COLUMNPROPAGATIONMODE']._serialized_start=1311
  _globals['_ASTSETOPERATIONENUMS_COLUMNPROPAGATIONMODE']._serialized_end=1377
  _globals['_ASTUNARYEXPRESSIONENUMS']._serialized_start=1379
  _globals['_ASTUNARYEXPRESSIONENUMS']._serialized_end=1506
  _globals['_ASTUNARYEXPRESSIONENUMS_OP']._serialized_start=1406
  _globals['_ASTUNARYEXPRESSIONENUMS_OP']._serialized_end=1506
  _globals['_ASTWINDOWFRAMEENUMS']._serialized_start=1508
  _globals['_ASTWINDOWFRAMEENUMS']._serialized_end=1563
  _globals['_ASTWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_start=1531
  _globals['_ASTWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_end=1563
  _globals['_ASTWINDOWFRAMEEXPRENUMS']._serialized_start=1566
  _globals['_ASTWINDOWFRAMEEXPRENUMS']._serialized_end=1718
  _globals['_ASTWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_start=1593
  _globals['_ASTWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_end=1718
  _globals['_ASTANYSOMEALLOPENUMS']._serialized_start=1720
  _globals['_ASTANYSOMEALLOPENUMS']._serialized_end=1799
  _globals['_ASTANYSOMEALLOPENUMS_OP']._serialized_start=1744
  _globals['_ASTANYSOMEALLOPENUMS_OP']._serialized_end=1799
  _globals['_ASTTRANSACTIONREADWRITEMODEENUMS']._serialized_start=1801
  _globals['_ASTTRANSACTIONREADWRITEMODEENUMS']._serialized_end=1887
  _globals['_ASTTRANSACTIONREADWRITEMODEENUMS_MODE']._serialized_start=1837
  _globals['_ASTTRANSACTIONREADWRITEMODEENUMS_MODE']._serialized_end=1887
  _globals['_ASTIMPORTSTATEMENTENUMS']._serialized_start=1889
  _globals['_ASTIMPORTSTATEMENTENUMS']._serialized_end=1951
  _globals['_ASTIMPORTSTATEMENTENUMS_IMPORTKIND']._serialized_start=1916
  _globals['_ASTIMPORTSTATEMENTENUMS_IMPORTKIND']._serialized_end=1951
  _globals['_ASTUNPIVOTCLAUSEENUMS']._serialized_start=1953
  _globals['_ASTUNPIVOTCLAUSEENUMS']._serialized_end=2036
  _globals['_ASTUNPIVOTCLAUSEENUMS_NULLFILTER']._serialized_start=1978
  _globals['_ASTUNPIVOTCLAUSEENUMS_NULLFILTER']._serialized_end=2036
  _globals['_ASTCREATESTATEMENTENUMS']._serialized_start=2039
  _globals['_ASTCREATESTATEMENTENUMS']._serialized_end=2229
  _globals['_ASTCREATESTATEMENTENUMS_SCOPE']._serialized_start=2066
  _globals['_ASTCREATESTATEMENTENUMS_SCOPE']._serialized_end=2132
  _globals['_ASTCREATESTATEMENTENUMS_SQLSECURITY']._serialized_start=2134
  _globals['_ASTCREATESTATEMENTENUMS_SQLSECURITY']._serialized_end=2229
  _globals['_ASTFUNCTIONPARAMETERENUMS']._serialized_start=2231
  _globals['_ASTFUNCTIONPARAMETERENUMS']._serialized_end=2325
  _globals['_ASTFUNCTIONPARAMETERENUMS_PROCEDUREPARAMETERMODE']._serialized_start=2260
  _globals['_ASTFUNCTIONPARAMETERENUMS_PROCEDUREPARAMETERMODE']._serialized_end=2325
  _globals['_ASTTEMPLATEDPARAMETERTYPEENUMS']._serialized_start=2328
  _globals['_ASTTEMPLATEDPARAMETERTYPEENUMS']._serialized_end=2489
  _globals['_ASTTEMPLATEDPARAMETERTYPEENUMS_TEMPLATEDTYPEKIND']._serialized_start=2362
  _globals['_ASTTEMPLATEDPARAMETERTYPEENUMS_TEMPLATEDTYPEKIND']._serialized_end=2489
  _globals['_ASTGENERATEDCOLUMNINFOENUMS']._serialized_start=2492
  _globals['_ASTGENERATEDCOLUMNINFOENUMS']._serialized_end=2629
  _globals['_ASTGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_start=2523
  _globals['_ASTGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_end=2584
  _globals['_ASTGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_start=2586
  _globals['_ASTGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_end=2629
  _globals['_ASTCOLUMNPOSITIONENUMS']._serialized_start=2631
  _globals['_ASTCOLUMNPOSITIONENUMS']._serialized_end=2709
  _globals['_ASTCOLUMNPOSITIONENUMS_RELATIVEPOSITIONTYPE']._serialized_start=2657
  _globals['_ASTCOLUMNPOSITIONENUMS_RELATIVEPOSITIONTYPE']._serialized_end=2709
  _globals['_ASTINSERTSTATEMENTENUMS']._serialized_start=2712
  _globals['_ASTINSERTSTATEMENTENUMS']._serialized_end=2932
  _globals['_ASTINSERTSTATEMENTENUMS_INSERTMODE']._serialized_start=2739
  _globals['_ASTINSERTSTATEMENTENUMS_INSERTMODE']._serialized_end=2806
  _globals['_ASTINSERTSTATEMENTENUMS_PARSEPROGRESS']._serialized_start=2808
  _globals['_ASTINSERTSTATEMENTENUMS_PARSEPROGRESS']._serialized_end=2932
  _globals['_ASTONCONFLICTCLAUSEENUMS']._serialized_start=2934
  _globals['_ASTONCONFLICTCLAUSEENUMS']._serialized_end=3016
  _globals['_ASTONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_start=2962
  _globals['_ASTONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_end=3016
  _globals['_ASTMERGEACTIONENUMS']._serialized_start=3018
  _globals['_ASTMERGEACTIONENUMS']._serialized_end=3102
  _globals['_ASTMERGEACTIONENUMS_ACTIONTYPE']._serialized_start=3041
  _globals['_ASTMERGEACTIONENUMS_ACTIONTYPE']._serialized_end=3102
  _globals['_ASTMERGEWHENCLAUSEENUMS']._serialized_start=3104
  _globals['_ASTMERGEWHENCLAUSEENUMS']._serialized_end=3222
  _globals['_ASTMERGEWHENCLAUSEENUMS_MATCHTYPE']._serialized_start=3131
  _globals['_ASTMERGEWHENCLAUSEENUMS_MATCHTYPE']._serialized_end=3222
  _globals['_ASTFILTERFIELDSARGENUMS']._serialized_start=3224
  _globals['_ASTFILTERFIELDSARGENUMS']._serialized_end=3302
  _globals['_ASTFILTERFIELDSARGENUMS_FILTERTYPE']._serialized_start=3251
  _globals['_ASTFILTERFIELDSARGENUMS_FILTERTYPE']._serialized_end=3302
  _globals['_ASTSAMPLESIZEENUMS']._serialized_start=3304
  _globals['_ASTSAMPLESIZEENUMS']._serialized_end=3368
  _globals['_ASTSAMPLESIZEENUMS_UNIT']._serialized_start=3326
  _globals['_ASTSAMPLESIZEENUMS_UNIT']._serialized_end=3368
  _globals['_ASTFOREIGNKEYACTIONSENUMS']._serialized_start=3370
  _globals['_ASTFOREIGNKEYACTIONSENUMS']._serialized_end=3463
  _globals['_ASTFOREIGNKEYACTIONSENUMS_ACTION']._serialized_start=3399
  _globals['_ASTFOREIGNKEYACTIONSENUMS_ACTION']._serialized_end=3463
  _globals['_ASTFOREIGNKEYREFERENCEENUMS']._serialized_start=3465
  _globals['_ASTFOREIGNKEYREFERENCEENUMS']._serialized_end=3543
  _globals['_ASTFOREIGNKEYREFERENCEENUMS_MATCH']._serialized_start=3496
  _globals['_ASTFOREIGNKEYREFERENCEENUMS_MATCH']._serialized_end=3543
  _globals['_ASTBREAKCONTINUESTATEMENTENUMS']._serialized_start=3545
  _globals['_ASTBREAKCONTINUESTATEMENTENUMS']._serialized_end=3650
  _globals['_ASTBREAKCONTINUESTATEMENTENUMS_BREAKCONTINUEKEYWORD']._serialized_start=3579
  _globals['_ASTBREAKCONTINUESTATEMENTENUMS_BREAKCONTINUEKEYWORD']._serialized_end=3650
  _globals['_ASTDROPSTATEMENTENUMS']._serialized_start=3652
  _globals['_ASTDROPSTATEMENTENUMS']._serialized_end=3741
  _globals['_ASTDROPSTATEMENTENUMS_DROPMODE']._serialized_start=3677
  _globals['_ASTDROPSTATEMENTENUMS_DROPMODE']._serialized_end=3741
  _globals['_ASTCREATEFUNCTIONSTMTBASEENUMS']._serialized_start=3744
  _globals['_ASTCREATEFUNCTIONSTMTBASEENUMS']._serialized_end=3909
  _globals['_ASTCREATEFUNCTIONSTMTBASEENUMS_DETERMINISMLEVEL']._serialized_start=3779
  _globals['_ASTCREATEFUNCTIONSTMTBASEENUMS_DETERMINISMLEVEL']._serialized_end=3909
  _globals['_ASTAUXLOADDATASTATEMENTENUMS']._serialized_start=3911
  _globals['_ASTAUXLOADDATASTATEMENTENUMS']._serialized_end=3998
  _globals['_ASTAUXLOADDATASTATEMENTENUMS_INSERTIONMODE']._serialized_start=3943
  _globals['_ASTAUXLOADDATASTATEMENTENUMS_INSERTIONMODE']._serialized_end=3998
  _globals['_ASTSPANNERINTERLEAVECLAUSEENUMS']._serialized_start=4000
  _globals['_ASTSPANNERINTERLEAVECLAUSEENUMS']._serialized_end=4077
  _globals['_ASTSPANNERINTERLEAVECLAUSEENUMS_TYPE']._serialized_start=4035
  _globals['_ASTSPANNERINTERLEAVECLAUSEENUMS_TYPE']._serialized_end=4077
  _globals['_ASTAFTERMATCHSKIPCLAUSEENUMS']._serialized_start=4080
  _globals['_ASTAFTERMATCHSKIPCLAUSEENUMS']._serialized_end=4215
  _globals['_ASTAFTERMATCHSKIPCLAUSEENUMS_AFTERMATCHSKIPTARGETTYPE']._serialized_start=4112
  _globals['_ASTAFTERMATCHSKIPCLAUSEENUMS_AFTERMATCHSKIPTARGETTYPE']._serialized_end=4215
  _globals['_ASTROWPATTERNANCHORENUMS']._serialized_start=4217
  _globals['_ASTROWPATTERNANCHORENUMS']._serialized_end=4297
  _globals['_ASTROWPATTERNANCHORENUMS_ANCHOR']._serialized_start=4245
  _globals['_ASTROWPATTERNANCHORENUMS_ANCHOR']._serialized_end=4297
  _globals['_ASTROWPATTERNOPERATIONENUMS']._serialized_start=4300
  _globals['_ASTROWPATTERNOPERATIONENUMS']._serialized_end=4431
  _globals['_ASTROWPATTERNOPERATIONENUMS_OPERATIONTYPE']._serialized_start=4331
  _globals['_ASTROWPATTERNOPERATIONENUMS_OPERATIONTYPE']._serialized_end=4431
  _globals['_ASTSYMBOLQUANTIFIERENUMS']._serialized_start=4433
  _globals['_ASTSYMBOLQUANTIFIERENUMS']._serialized_end=4532
  _globals['_ASTSYMBOLQUANTIFIERENUMS_SYMBOL']._serialized_start=4461
  _globals['_ASTSYMBOLQUANTIFIERENUMS_SYMBOL']._serialized_end=4532
  _globals['_ASTGRAPHNODETABLEREFERENCEENUMS']._serialized_start=4534
  _globals['_ASTGRAPHNODETABLEREFERENCEENUMS']._serialized_end=4654
  _globals['_ASTGRAPHNODETABLEREFERENCEENUMS_NODEREFERENCETYPE']._serialized_start=4569
  _globals['_ASTGRAPHNODETABLEREFERENCEENUMS_NODEREFERENCETYPE']._serialized_end=4654
  _globals['_ASTGRAPHLABELOPERATIONENUMS']._serialized_start=4656
  _globals['_ASTGRAPHLABELOPERATIONENUMS']._serialized_end=4760
  _globals['_ASTGRAPHLABELOPERATIONENUMS_OPERATIONTYPE']._serialized_start=4687
  _globals['_ASTGRAPHLABELOPERATIONENUMS_OPERATIONTYPE']._serialized_end=4760
  _globals['_ASTGRAPHEDGEPATTERNENUMS']._serialized_start=4762
  _globals['_ASTGRAPHEDGEPATTERNENUMS']._serialized_end=4867
  _globals['_ASTGRAPHEDGEPATTERNENUMS_EDGEORIENTATION']._serialized_start=4790
  _globals['_ASTGRAPHEDGEPATTERNENUMS_EDGEORIENTATION']._serialized_end=4867
  _globals['_ASTGRAPHPATHMODEENUMS']._serialized_start=4869
  _globals['_ASTGRAPHPATHMODEENUMS']._serialized_end=4977
  _globals['_ASTGRAPHPATHMODEENUMS_PATHMODE']._serialized_start=4894
  _globals['_ASTGRAPHPATHMODEENUMS_PATHMODE']._serialized_end=4977
  _globals['_ASTGRAPHPATHSEARCHPREFIXENUMS']._serialized_start=4980
  _globals['_ASTGRAPHPATHSEARCHPREFIXENUMS']._serialized_end=5159
  _globals['_ASTGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_start=5014
  _globals['_ASTGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_end=5159
  _globals['_ASTLOCKMODEENUMS']._serialized_start=5161
  _globals['_ASTLOCKMODEENUMS']._serialized_end=5224
  _globals['_ASTLOCKMODEENUMS_LOCKSTRENGTHSPEC']._serialized_start=5181
  _globals['_ASTLOCKMODEENUMS_LOCKSTRENGTHSPEC']._serialized_end=5224
  _globals['_ASTBRACEDCONSTRUCTORLHSENUMS']._serialized_start=5226
  _globals['_ASTBRACEDCONSTRUCTORLHSENUMS']._serialized_end=5336
  _globals['_ASTBRACEDCONSTRUCTORLHSENUMS_OPERATION']._serialized_start=5258
  _globals['_ASTBRACEDCONSTRUCTORLHSENUMS_OPERATION']._serialized_end=5336
  _globals['_ASTALTERINDEXSTATEMENTENUMS']._serialized_start=5338
  _globals['_ASTALTERINDEXSTATEMENTENUMS']._serialized_end=5435
  _globals['_ASTALTERINDEXSTATEMENTENUMS_INDEXTYPE']._serialized_start=5369
  _globals['_ASTALTERINDEXSTATEMENTENUMS_INDEXTYPE']._serialized_end=5435
# @@protoc_insertion_point(module_scope)
