# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_token_list.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_token_list.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&zetasql/public/simple_token_list.proto\x12\x07zetasql\"I\n\x14SimpleTokenListProto\x12+\n\ntext_token\x18\x02 \x03(\x0b\x32\x17.zetasql.TextTokenProtoJ\x04\x08\x01\x10\x02\"[\n\x0eTextTokenProto\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\tattribute\x18\x02 \x01(\x04\x12(\n\x0bindex_token\x18\x03 \x03(\x0b\x32\x13.zetasql.TokenProto\"-\n\nTokenProto\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\tattribute\x18\x02 \x01(\x04\x42+\n\x12\x63om.google.zetasqlB\x15SimpleTokenListProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_token_list_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\025SimpleTokenListProtos'
  _globals['_SIMPLETOKENLISTPROTO']._serialized_start=51
  _globals['_SIMPLETOKENLISTPROTO']._serialized_end=124
  _globals['_TEXTTOKENPROTO']._serialized_start=126
  _globals['_TEXTTOKENPROTO']._serialized_end=217
  _globals['_TOKENPROTO']._serialized_start=219
  _globals['_TOKENPROTO']._serialized_end=264
# @@protoc_insertion_point(module_scope)
