# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/feature_label_dictionary.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/feature_label_dictionary.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/public/feature_label_dictionary.proto\x12\x07zetasql\"\xf6\x02\n\x1b\x46\x65\x61tureLabelDictionaryProto\x12M\n\rlabel_mapping\x18\x01 \x03(\x0b\x32\x36.zetasql.FeatureLabelDictionaryProto.LabelMappingEntry\x12O\n\x0e\x65ncoded_labels\x18\x02 \x03(\x0b\x32\x37.zetasql.FeatureLabelDictionaryProto.EncodedLabelsEntry\x1a\x33\n\x11LabelMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x1d\n\x08LabelSet\x12\x11\n\x05label\x18\x01 \x03(\x05\x42\x02\x10\x01\x1a\x63\n\x12\x45ncodedLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.zetasql.FeatureLabelDictionaryProto.LabelSet:\x02\x38\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.feature_label_dictionary_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FEATURELABELDICTIONARYPROTO_LABELMAPPINGENTRY']._loaded_options = None
  _globals['_FEATURELABELDICTIONARYPROTO_LABELMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FEATURELABELDICTIONARYPROTO_LABELSET'].fields_by_name['label']._loaded_options = None
  _globals['_FEATURELABELDICTIONARYPROTO_LABELSET'].fields_by_name['label']._serialized_options = b'\020\001'
  _globals['_FEATURELABELDICTIONARYPROTO_ENCODEDLABELSENTRY']._loaded_options = None
  _globals['_FEATURELABELDICTIONARYPROTO_ENCODEDLABELSENTRY']._serialized_options = b'8\001'
  _globals['_FEATURELABELDICTIONARYPROTO']._serialized_start=59
  _globals['_FEATURELABELDICTIONARYPROTO']._serialized_end=433
  _globals['_FEATURELABELDICTIONARYPROTO_LABELMAPPINGENTRY']._serialized_start=250
  _globals['_FEATURELABELDICTIONARYPROTO_LABELMAPPINGENTRY']._serialized_end=301
  _globals['_FEATURELABELDICTIONARYPROTO_LABELSET']._serialized_start=303
  _globals['_FEATURELABELDICTIONARYPROTO_LABELSET']._serialized_end=332
  _globals['_FEATURELABELDICTIONARYPROTO_ENCODEDLABELSENTRY']._serialized_start=334
  _globals['_FEATURELABELDICTIONARYPROTO_ENCODEDLABELSENTRY']._serialized_end=433
# @@protoc_insertion_point(module_scope)
