# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/proto/type_annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/proto/type_annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*zetasql/public/proto/type_annotation.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\xe5\x03\n\x0b\x46ieldFormat\"\xd5\x03\n\x06\x46ormat\x12\x12\n\x0e\x44\x45\x46\x41ULT_FORMAT\x10\x00\x12\x08\n\x04\x44\x41TE\x10\x01\x12\x15\n\x11TIMESTAMP_SECONDS\x10\x02\x12\x14\n\x10TIMESTAMP_MILLIS\x10\x03\x12\x14\n\x10TIMESTAMP_MICROS\x10\x04\x12\x13\n\x0fTIMESTAMP_NANOS\x10\x05\x12\x13\n\x0fTIMESTAMP_PICOS\x10\x14\x12\r\n\tTIMESTAMP\x10\x15\x12\x10\n\x0c\x44\x41TE_DECIMAL\x10\x06\x12\x0f\n\x0bTIME_MICROS\x10\x07\x12\x13\n\x0f\x44\x41TETIME_MICROS\x10\x08\x12\x18\n\x14ST_GEOGRAPHY_ENCODED\x10\t\x12\x0b\n\x07NUMERIC\x10\n\x12\x0e\n\nBIGNUMERIC\x10\x0b\x12\x08\n\x04JSON\x10\x0c\x12\x0c\n\x08INTERVAL\x10\x0e\x12\r\n\tTOKENLIST\x10\x0f\x12\x17\n\x13RANGE_DATES_ENCODED\x10\x10\x12\x1b\n\x17RANGE_DATETIMES_ENCODED\x10\x11\x12\x1c\n\x18RANGE_TIMESTAMPS_ENCODED\x10\x12\x12\x08\n\x04UUID\x10\x13\x12=\n0__FieldFormat_Type__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"\xa7\x01\n\x12\x44\x65precatedEncoding\"\x90\x01\n\x08\x45ncoding\x12\x14\n\x10\x44\x45\x46\x41ULT_ENCODING\x10\x00\x12\x10\n\x0c\x44\x41TE_DECIMAL\x10\x01\x12\x15\n\rDATE_PACKED32\x10\x01\x1a\x02\x08\x01\x12\x41\n4__FieldFormat_Encoding__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x1a\x02\x10\x01:M\n\x06\x66ormat\x12\x1d.google.protobuf.FieldOptions\x18\xcb\xeb\xe1  \x01(\x0e\x32\x1b.zetasql.FieldFormat.Format:K\n\x04type\x12\x1d.google.protobuf.FieldOptions\x18\xe5\xaa\xdf\x17 \x01(\x0e\x32\x1b.zetasql.FieldFormat.Format:X\n\x08\x65ncoding\x12\x1d.google.protobuf.FieldOptions\x18\xa7\xf9\xfe\x1d \x01(\x0e\x32$.zetasql.DeprecatedEncoding.Encoding:<\n\x0cuse_defaults\x12\x1d.google.protobuf.FieldOptions\x18\xbf\xa6\xde\x17 \x01(\x08:\x04true:D\n\x12use_field_defaults\x12\x1f.google.protobuf.MessageOptions\x18\x82\xf9\xd6\x17 \x01(\x08:\x04trueB,\n\x12\x63om.google.zetasqlB\x13TypeAnnotationProto\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.proto.type_annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\023TypeAnnotationProto\370\001\001'
  _globals['_DEPRECATEDENCODING_ENCODING']._loaded_options = None
  _globals['_DEPRECATEDENCODING_ENCODING']._serialized_options = b'\020\001'
  _globals['_DEPRECATEDENCODING_ENCODING'].values_by_name["DATE_PACKED32"]._loaded_options = None
  _globals['_DEPRECATEDENCODING_ENCODING'].values_by_name["DATE_PACKED32"]._serialized_options = b'\010\001'
  _globals['_FIELDFORMAT']._serialized_start=90
  _globals['_FIELDFORMAT']._serialized_end=575
  _globals['_FIELDFORMAT_FORMAT']._serialized_start=106
  _globals['_FIELDFORMAT_FORMAT']._serialized_end=575
  _globals['_DEPRECATEDENCODING']._serialized_start=578
  _globals['_DEPRECATEDENCODING']._serialized_end=745
  _globals['_DEPRECATEDENCODING_ENCODING']._serialized_start=601
  _globals['_DEPRECATEDENCODING_ENCODING']._serialized_end=745
# @@protoc_insertion_point(module_scope)
